MSG_HASH(
      MSG_COMPILER,
      "Compilatore"
      )
MSG_HASH(
      MSG_UNKNOWN_COMPILER,
      "Compilatore sconosciuto"
      )
MSG_HASH(
      MSG_DEVICE_DISCONNECTED_FROM_PORT,
      "Dispositivo disconnesso dalla porta"
      )
MSG_HASH(
      MSG_UNKNOWN_NETPLAY_COMMAND_RECEIVED,
      "Comando sconosciuto del netplay ricevuto"
      )
MSG_HASH(
      MSG_FILE_ALREADY_EXISTS_SAVING_TO_BACKUP_BUFFER,
      "Il file esiste già. Salvataggio in buffer di backup"
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM,
      "Connessione da: \"%s\""
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM_NAME,
      "Hai connessione da: \"%s (%s)\""
      )
MSG_HASH(
      MSG_PUBLIC_ADDRESS,
      "Indirizzo pubblico"
      )
MSG_HASH(
      MSG_NO_ARGUMENTS_SUPPLIED_AND_NO_MENU_BUILTIN,
      "Nessun argomento fornito e nessun menu incorporato, visualizzazione della guida..."
      )
MSG_HASH(
      MSG_SETTING_DISK_IN_TRAY,
      "impostazioni del disco nel cassetto"
      )
MSG_HASH(
      MSG_WAITING_FOR_CLIENT,
      "In attesa di un client ..."
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_LEFT_THE_GAME,
      "Sei uscito dal gioco"
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_JOINED_AS_PLAYER_N,
      "Sei entrato come giocatore %u"
      )
MSG_HASH(
      MSG_NETPLAY_ENDIAN_DEPENDENT,
      "Questo core non supporta la rete di inter-architettura tra questi sistemi"
      )
MSG_HASH(
      MSG_NETPLAY_PLATFORM_DEPENDENT,
      "Questo core non supporta la rete di inter-architettura"
      )
MSG_HASH(
      MSG_NETPLAY_ENTER_PASSWORD,
      "inserisci la password del server netplay:"
      )
MSG_HASH(
      MSG_NETPLAY_INCORRECT_PASSWORD,
      "Password errata"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_NAMED_HANGUP,
      "\"%s\" si è disconnesso"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_HANGUP,
      "Un client del netplay si è scollegato"
      )
MSG_HASH(
      MSG_NETPLAY_CLIENT_HANGUP,
      "Netplay disconnesso"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_UNPRIVILEGED,
      "Non hai il permesso di giocare"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_NO_SLOTS,
      "Non ci sono slot liberi per i giocatori"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY,
      "Non è possibile passare in modalità gioco"
      )
MSG_HASH(
      MSG_NETPLAY_PEER_PAUSED,
      "Netplay peer \"%s\"in pausa"
      )
MSG_HASH(
      MSG_NETPLAY_CHANGED_NICK,
      "Il tuo nickname è cambiato in \"%s\""
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHARED_CONTEXT,
      "Fornisce i core hardware nel proprio contesto privato. Evita di assumere cambiamenti di stato hardware tra i fotogrammi."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_SETTINGS,
      "Regola le impostazioni relative all'aspetto della schermata del menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC,
      "Sincronizzare duramente la CPU e la GPU. Riduce la latenza al costo delle prestazioni."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_THREADED,
      "Migliora le prestazioni a costo di latenza e dello stuttering video. Utilizzarlo solo se non è possibile ottenere una piena velocità."
      )
MSG_HASH(
      MSG_AUDIO_VOLUME,
      "Volume audio"
      )
MSG_HASH(
      MSG_AUTODETECT,
      "Trovato automaticamente"
      )
MSG_HASH(
      MSG_AUTOLOADING_SAVESTATE_FROM,
      "Carica automaticamente il salvataggio da"
      )
MSG_HASH(
      MSG_CAPABILITIES,
      "Funzionalità"
      )
MSG_HASH(
      MSG_CONNECTING_TO_NETPLAY_HOST,
      "Connessione al host del netplay"
      )
MSG_HASH(
      MSG_CONNECTING_TO_PORT,
      "Connessione alla porta"
      )
MSG_HASH(
      MSG_CONNECTION_SLOT,
      "Connessione allo slot"
      )
MSG_HASH(
      MSG_SORRY_UNIMPLEMENTED_CORES_DONT_DEMAND_CONTENT_NETPLAY,
      "Spiacente, non è stato implementato: i core che non richiedono contenuti non possono partecipare al netplay"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_PASSWORD,
      "Password"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_SETTINGS,
      "Accounts Cheevos"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_USERNAME,
      "Nome utente"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST,
      "Accounts"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST_END,
      "Accounts List Endpoint"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Retro Achievements"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST,
      "Lista Achievement"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST_HARDCORE,
      "Lista Achievement(Hardcore)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_CONTENT_LIST,
      "Scansione Dei Contenuti"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS_LIST,
      "Configurazioni"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_TAB,
      "Importa contenuto"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_NETPLAY_TAB,
      "Camere Netplay "
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASK_ARCHIVE,
      "Invita"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASSETS_DIRECTORY,
      "Assets"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_BLOCK_FRAMES,
      "Blocchi Frame"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DEVICE,
      "Dispositivo audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DRIVER,
      "Driver audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DSP_PLUGIN,
      "Plugin Audio DSP "
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE,
      "Audio Abilitato"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_FILTER_DIR,
      "Filtro Audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_TURBO_DEADZONE_LIST,
      "Turbo/Deadzone"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_LATENCY,
      "Latenza audio (ms)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MAX_TIMING_SKEW,
      "Temporizzazione massima audio Skew"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MUTE,
      "Disattiva Audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_OUTPUT_RATE,
      "Frequenza audio di output (Hz)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RATE_CONTROL_DELTA,
      "Audio Dinamico di controllo Delta "
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_DRIVER,
      "Audio Resampler Driver"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SETTINGS,
      "Audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SYNC,
      "Sincronizzazione Audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_VOLUME,
      "Livello del Volume Audio (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_EXCLUSIVE_MODE,
      "WASAPI Modalità Esclusiva"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_FLOAT_FORMAT,
      "WASAPI Float Format"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_SH_BUFFER_LENGTH,
      "WASAPI ha condiviso la lunghezza del Buffer"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTOSAVE_INTERVAL,
      "Intervallo di salvataggio automatico SaveRAM"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_OVERRIDES_ENABLE,
      "Carica automaticamente il file Override"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_REMAPS_ENABLE,
      "Carica automaticamente i file remap"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_SHADERS_ENABLE,
      "Carica Shader predefiniti automaticamente"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_BACK,
      "Indietro"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_CONFIRM,
      "Conferma"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_INFO,
      "Info"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_QUIT,
      "Abbandona"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_DOWN,
      "Scorrere verso il basso"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_UP,
      "Scorrere verso l'alto"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_START,
      "Avvia"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_KEYBOARD,
      "Pulsante Tastiera"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_MENU,
      "Pulsante Menu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS,
      "Controlli di base del menu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_CONFIRM,
      "Conferma/OK"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_INFO,
      "Info"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_QUIT,
      "Abbandona"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_SCROLL_UP,
      "Scorri verso l'alto"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_START,
      "Defaults"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_KEYBOARD,
      "Pulsante Keyboard"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_MENU,
      "Pulsante Menu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLOCK_SRAM_OVERWRITE,
      "Non sovrascrivere il SaveRAM durante il caricamento del salvataggio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLUETOOTH_ENABLE,
      "Bluetooth Abilitato"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BUILDBOT_ASSETS_URL,
      "URL degli asset Buildbot"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CACHE_DIRECTORY,
      "Cache"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_ALLOW,
      "Consenti Fotocamera"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_DRIVER,
      "Driver della Fotocamera"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT,
      "Cheat"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_APPLY_CHANGES,
      "Applica i cambiamenti"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_DATABASE_PATH,
      "File Cheat "
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE,
      "File Cheat "
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_LOAD,
      "Carica File Cheat "
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_SAVE_AS,
      "Salva il file cheat come"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_NUM_PASSES,
      "Cheat Passes"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_DESCRIPTION,
      "Descrizione"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Modalità Achievements Hardcore"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ACHIEVEMENTS,
      "Achievements Bloccati:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ENTRY,
      "Bloccato"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_SETTINGS,
      "Retro Achievements"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_TEST_UNOFFICIAL,
      "Testa gli Achievements non ufficiali"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_VERBOSE_ENABLE,
      "Modalità Achievements Verbose "
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ACHIEVEMENTS,
      "Achievements sbloccati:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY,
      "Sbloccato"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CLOSE_CONTENT,
      "Chiudi contenuto"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG,
      "Configurazione"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS,
      "Carica Configurazione"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATION_SETTINGS,
      "Configurazione"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG_SAVE_ON_EXIT,
      "Salva la configurazione all' uscita"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_COLLECTION_LIST,
      "Collezioni"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DATABASE_DIRECTORY,
      "Database"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DIR,
      "Contenuto"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_SIZE,
      "Dimensione dell'elenco cronologia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_REMOVE,
      "Rimuovi le voci")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SETTINGS,
      "Menu Rapido")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIR,
      "Downloads")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIRECTORY,
      "Downloads")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_CHEAT_OPTIONS,
      "Cheats")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_COUNTERS,
      "Contatori di core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ENABLE,
      "Visualizza il nome del core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFORMATION,
      "Informazioni del core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_AUTHORS,
      "Autori")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CATEGORIES,
      "Categorie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_LABEL,
      "Etichetta Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_NAME,
      "Nome del Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_FIRMWARE,
      "Firmware")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_LICENSES,
      "Licenza(e)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_PERMISSIONS,
      "Autorizzazioni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SUPPORTED_EXTENSIONS,
      "Estensioni supportate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_MANUFACTURER,
      "Produttore del sistema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_NAME,
      "Nome del sistema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INPUT_REMAPPING_OPTIONS,
      "Controlli")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_LIST,
      "Carica Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_OPTIONS,
      "Opzioni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SETTINGS,
      "Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SET_SUPPORTS_NO_CONTENT_ENABLE,
      "Avvia automaticamente un Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "Estrarre automaticamente l'archivio scaricato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_BUILDBOT_URL,
      "Buildbot Cores URL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_LIST,
      "Aggiorna Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_SETTINGS,
      "Aggiorna")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_ARCHITECTURE,
      "Architettura della CPU:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_CORES,
      "CPU dei Core:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_DIRECTORY,
      "Cursore")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_MANAGER,
      "Gestore del Cursore")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CUSTOM_RATIO,
      "Custom Ratio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_MANAGER,
      "Gestore Database ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_SELECTION,
      "Selezione del database")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DELETE_ENTRY,
      "Rimuovi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FAVORITES,
      "Avvia da directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_CONTENT,
      "<Contenuto della directory>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_DEFAULT,
      "<Default>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NONE,
      "<Nessuno>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NOT_FOUND,
      "Directory non trovata.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_SETTINGS,
      "Directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_CYCLE_TRAY_STATUS,
      "Stato del ciclo nel vassoio del disco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_IMAGE_APPEND,
      "Aggiungere Immagine disco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_INDEX,
      "Indice del Disco ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_OPTIONS,
      "Controllo del Disco ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DONT_CARE,
      "Non importa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOADED_FILE_DETECT_CORE_LIST,
      "Downloads")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE,
      "Scarica Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE_CONTENT,
      "Downloader dei contenuti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_ENABLE,
      "DPI Override Abilitato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_VALUE,
      "DPI Override")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DRIVER_SETTINGS,
      "Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DUMMY_ON_CORE_SHUTDOWN,
      "Carica Dummy alla chiusura del Core ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHECK_FOR_MISSING_FIRMWARE,
      "Controlla il firmware mancante prima del caricamento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPER,
      "Sfondo dinamico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPERS_DIRECTORY,
      "Sfondi dinamici")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHEEVOS_ENABLE,
      "Abilita Achievements")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_HOVER_COLOR,
      "Colore al passaggio del mouse")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_NORMAL_COLOR,
      "Voce di Menu con colore normale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FALSE,
      "Falso")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FASTFORWARD_RATIO,
      "Velocità massima di esercizio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FAVORITES_TAB,
      "Preferiti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FPS_SHOW,
      "Visualizzazione framerate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_ENABLE,
      "Limita la velocità massima di esercizio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_SETTINGS,
      "Riavvolgimento e Fotogrammi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRONTEND_COUNTERS,
      "Contatori di frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS,
      "Carica il Contenuto Specifico delle opzioni del Core Automaticamente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_CREATE,
      "Crea file delle opzioni di gioco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_IN_USE,
      "File delle opzioni di gioco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP,
      "Aiuto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_AUDIO_VIDEO_TROUBLESHOOTING,
      "Risoluzione dei problemi audio/video")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CHANGE_VIRTUAL_GAMEPAD,
      "Cambia la sovrapposizione virtuale del gamepad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CONTROLS,
      "Controlli del menu di base")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LIST,
      "Aiuto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LOADING_CONTENT,
      "Caricamento del contenuto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_SCANNING_CONTENT,
      "Scansione del contenuto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_WHAT_IS_A_CORE,
      "Che cos'è un core?")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_LIST_ENABLE,
      "Abilita l'elenco della cronologia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_TAB,
      "Cronologia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HORIZONTAL_MENU,
      "Menu Orizzontale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_IMAGES_TAB,
      "Immagini")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION,
      "Informazioni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION_LIST,
      "Informazioni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ADC_TYPE,
      "Da analogico a digitale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ALL_USERS_CONTROL_MENU,
      "Menu di controllo di tutti gli utenti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X,
      "Analogico sinistro X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_MINUS,
      "Analogico sinistro X- (sinistro)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_PLUS,
      "Analogico sinistro X+ (destra)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y,
      "Analogico sinistro Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_MINUS,
      "Analogico sinistro Y- (su)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_PLUS,
      "Analogico sinistro Y+ (giù)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X,
      "Analogico Destro X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_MINUS,
      "Analogico Destro X- (sinistro)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_PLUS,
      "Analogico Destro X+ (destra)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y,
      "Analogico Destro Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_MINUS,
      "Analogico Destro Y- (su)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_PLUS,
      "Analogico Destro Y+ (giù)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_TRIGGER,
      "Trigger della Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_RELOAD,
      "Ricarica della pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_A,
      "Pistola Aux A")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_B,
      "Pistola Aux B")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_C,
      "Pistola Aux C")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_START,
      "Pistola Start")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_SELECT,
      "Pistola Select")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_UP,
      "Pistola D-pad su")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_DOWN,
      "Pistola D-pad giu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_LEFT,
      "Pistola D-pad Sinistra")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_RIGHT,
      "Pistola D-pad Destro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AUTODETECT_ENABLE,
      "Abilita Autoconfigurazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AXIS_THRESHOLD,
      "Deadzone dello stick analogico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_INPUT_SWAP_OK_CANCEL,
      "Scambia i pulsanti OK & Annulla ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_ALL,
      "Bind All")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_DEFAULT_ALL,
      "Bind Default All")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_TIMEOUT,
      "Bind Timeout")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_HIDE_UNBOUND,
      "Nascondi i descrittori di input di core non legati")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_LABEL_SHOW,
      "Visualizza le etichette dei descrittori di input")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_INDEX,
      "Indice del dispositivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_TYPE,
      "Tipo di dispositivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_INDEX,
      "Indice del mouse")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DRIVER,
      "Driver di input")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DUTY_CYCLE,
      "Ciclo di lavoro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_HOTKEY_BINDS,
      "Input Hotkey Binds")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ICADE_ENABLE,
      "Mappatura del Gamepad su tastiera Abilitato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_A,
      "Pulsante A (destra)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_B,
      "Pulsante B (giù)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_DOWN,
      "D-pad giù")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L2,
      "Pulsante L2 (trigger)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L3,
      "Pulsante L3 (thumb)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L,
      "Pulsante L (shoulder)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_LEFT,
      "D-pad sinistro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R2,
      "Pulsante R2 (trigger)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R3,
      "Pulsante R3 (thumb)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R,
      "Pulsante R (shoulder)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_RIGHT,
      "D-pad Destro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_SELECT,
      "Pulsante Select")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_START,
      "Pulsante Start")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_UP,
      "D-pad su")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_X,
      "Pulsante X (in alto)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_Y,
      "Pulsante Y (sinistro)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEY,
      "(Tasto: %s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_LEFT,
      "Mouse 1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_RIGHT,
      "Mouse 2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_MIDDLE,
      "Mouse 3")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON4,
      "Mouse 4")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON5,
      "Mouse 5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_UP,
      "Wheel Up")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_DOWN,
      "Wheel Down")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_UP,
      "Wheel Left")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_DOWN,
      "Wheel Right")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEYBOARD_GAMEPAD_MAPPING_TYPE,
      "Tipo di mappatura del gamepad della tastiera")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MAX_USERS,
      "Massimo numero di Utenti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "Pulsanti Combo gamepad per il menù a comparsa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_MINUS,
      "Indice dei Cheat -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_PLUS,
      "Indice dei Cheat +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_TOGGLE,
      "Pulsante Cheat ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_EJECT_TOGGLE,
      "Pulsante espulsione Disco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_NEXT,
      "Disco successivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_PREV,
      "Disco precedente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_ENABLE_HOTKEY,
      "Abilita hotkeys")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_HOLD_KEY,
      "Andare avanti veloce")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_KEY,
      "Pulsante per avanzamento veloce ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FRAMEADVANCE,
      "Frameadvance")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FULLSCREEN_TOGGLE_KEY,
      "Pulsante per lo schermo intero ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GRAB_MOUSE_TOGGLE,
      "Pulsante per il tocco del mouse")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GAME_FOCUS_TOGGLE,
      "Pulsante Game focus ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_LOAD_STATE_KEY,
      "Pulsante Carica Stato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MENU_TOGGLE,
      "Pulsante per il Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MOVIE_RECORD_TOGGLE,
      "Pulsante registratore Film")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MUTE,
      "Pulsante per disattivare l'audio ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_NETPLAY_GAME_WATCH,
      "Pulsante Netplay per la modalità giocatore/spettatore")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OSK,
      "Pulsante per la tastiera su schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OVERLAY_NEXT,
      "Overlay successivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_PAUSE_TOGGLE,
      "Pulsante Pausa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_QUIT_KEY,
      "Pulsante per uscire da RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_RESET,
      "Resetta il gioco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_REWIND,
      "Riavvolgimento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SAVE_STATE_KEY,
      "Pulsante Salva Stato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SCREENSHOT,
      "Effettua uno screenshot")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_NEXT,
      "Shader successivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_PREV,
      "Shader Precedente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SLOWMOTION_HOLD_KEY,
      "Slow motion")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_MINUS,
      "Slot di Salvataggio -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_PLUS,
      "Slot di Salvataggio +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_DOWN,
      "Volume -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_UP,
      "Volume +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_ENABLE,
      "Visualizza Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_HIDE_IN_MENU,
      "Nascondi Overlay nel Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS,
      "Visualizza Inputs su Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS_PORT,
      "Visualizza Inputs Listen Port")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR,
      "Poll Type Behavior")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_EARLY,
      "Anticipato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_LATE,
      "Ritardato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_NORMAL,
      "Normale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_PREFER_FRONT_TOUCH,
      "Preferisco il Touch frontale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAPPING_DIRECTORY,
      "Input di rimappatura")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAP_BINDS_ENABLE,
      "Rimappa Binds Abilitato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SAVE_AUTOCONFIG,
      "Salva file Autoconfig")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SETTINGS,
      "Input")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SMALL_KEYBOARD_ENABLE,
      "Piccola Tastiera Abilitata")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TOUCH_ENABLE,
      "Touch Abilitato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_ENABLE,
      "Turbo Abilitato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_PERIOD,
      "Turbo Periodico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_USER_BINDS,
      "Input utente %u Binds")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INTERNAL_STORAGE_STATUS,
      "Stato di archiviazione interna")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_AUTOCONFIG_DIR,
      "Input Autoconfig")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_DRIVER,
      "Driver del Joypad ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LAKKA_SERVICES,
      "Servizi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_SIMPLIFIED,
      "Cinese (Semplificato)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_TRADITIONAL,
      "Cinese (Tradizionale)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_DUTCH,
      "Olandese")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ENGLISH,
      "Inglese")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ESPERANTO,
      "Esperanto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_FRENCH,
      "Francese")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_GERMAN,
      "Tedesco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ITALIAN,
      "Italiano")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_JAPANESE,
      "Giapponese")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_KOREAN,
      "Coreano")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_POLISH,
      "Polacco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_BRAZIL,
      "Portoghese (Brasiliano)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_PORTUGAL,
      "Portoghese (Portogallo)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_RUSSIAN,
      "Russo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_SPANISH,
      "Spagnolo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_VIETNAMESE,
      "Vietnamese")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ARABIC,
      "Arabic")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LEFT_ANALOG,
      "Analogico sinistro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_DIR_PATH,
      "Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_INFO_PATH,
      "Informazione sul Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_LOG_LEVEL,
      "Core Logging Level")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LINEAR,
      "Lineare")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_ARCHIVE,
      "Carica Archivio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_HISTORY,
      "Carica Recenti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST,
      "Carica Contenuto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_STATE,
      "Carica Stato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_ALLOW,
      "Consenti Posizione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_DRIVER,
      "Posizione del Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOGGING_SETTINGS,
      "Logging")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOG_VERBOSITY,
      "Logging Verbosity")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MAIN_MENU,
      "Menu principale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MANAGEMENT,
      "Impostazioni del Database ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME,
      "Colore del tema di Menu ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE,
      "Blu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE_GREY,
      "Blu con Grigio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_DARK_BLUE,
      "Blu scuro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_GREEN,
      "Verde")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_NVIDIA_SHIELD,
      "Shield")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_RED,
      "Rosso")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_YELLOW,
      "Giallo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_FOOTER_OPACITY,
      "Opacità di piè di pagina")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_HEADER_OPACITY,
      "Opacità di intestazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DRIVER,
      "Driver del Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENUM_THROTTLE_FRAMERATE,
      "Frequenza dei fotogrammi nel menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FILE_BROWSER_SETTINGS,
      "Impostazioni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_LINEAR_FILTER,
      "Filtro lineare del Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_HORIZONTAL_ANIMATION,
      "Animazione orizzontale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SETTINGS,
      "Impostazioni Aspetto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER,
      "Sfondo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER_OPACITY,
      "Opacità Sfondo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MISSING,
      "Manca")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MORE,
      "...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MOUSE_ENABLE,
      "Supporto del Mouse")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MULTIMEDIA_SETTINGS,
      "Multimedia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MUSIC_TAB,
      "Musica")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "Filtra estensioni sconosciute")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_WRAPAROUND,
      "Navigazione Wrap-Around")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NEAREST,
      "Nearest")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY,
      "Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ALLOW_SLAVES,
      "Attiva modalità Client Slave")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_CHECK_FRAMES,
      "Controllo Netplay Frames")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "Input della latenza del Frames")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "Input Latency Frames Range")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DELAY_FRAMES,
      "Netplay Delay Frames")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISCONNECT,
      "Scollegare dall'host netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE,
      "Netplay Abilitato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_CLIENT,
      "Connetti all'host netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_HOST,
      "Avvia l'host netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISABLE_HOST,
      "Ferma l'host netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_IP_ADDRESS,
      "Indirizzo Server")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LAN_SCAN_SETTINGS,
      "Scansione della rete locale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_MODE,
      "Netplay Client Abilitato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NICKNAME,
      "Nome utente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PASSWORD,
      "Password del Server")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PUBLIC_ANNOUNCE,
      "Annuncia pubblicamente il Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REQUIRE_SLAVES,
      "Disattiva i client in modalità non slave")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SETTINGS,
      "Impostazioni Netplay ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_AS_SPECTATOR,
      "Modalità Spettatore Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_STATELESS_MODE,
      "Modalità senza stato del Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATE_PASSWORD,
      "Server Spectate-Only Password")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATOR_MODE_ENABLE,
      "Netplay Spettatore Abilitato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_TCP_UDP_PORT,
      "Netplay TCP Port")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NAT_TRAVERSAL,
      "Netplay NAT Traversal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_ENABLE,
      "Comandi di rete")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_PORT,
      "Comando della porta di rete")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_INFORMATION,
      "Informazioni sulla rete")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_ENABLE,
      "Rete Gamepad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_PORT,
      "Porta della rete remota di Base")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_SETTINGS,
      "Rete")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO,
      "No")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NONE,
      "Nessuno")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NOT_AVAILABLE,
      "N/A")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ACHIEVEMENTS_TO_DISPLAY,
      "Nessun achievements da visualizzare.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE,
      "Nessun Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORES_AVAILABLE,
      "Nessun core disponibile.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_INFORMATION_AVAILABLE,
      "Nessuna informazione sul core disponibile.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_OPTIONS_AVAILABLE,
      "Nessuna opzione del core disponibile.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ENTRIES_TO_DISPLAY,
      "Nessuna voce da visualizzare.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_HISTORY_AVAILABLE,
      "Nessuna cronologia disponibile.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_INFORMATION_AVAILABLE,
      "Nessuna informazione disponibile.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ITEMS,
      "Nessun elemento.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETPLAY_HOSTS_FOUND,
      "Nessun host netplay trovato.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETWORKS_FOUND,
      "Nessuna rete trovata.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PERFORMANCE_COUNTERS,
      "Nessun contatore delle prestazioni.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLISTS,
      "Nessuna playlists.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLIST_ENTRIES_AVAILABLE,
      "Nessuna voce della playlist disponibile.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SETTINGS_FOUND,
      "Nessuna impostazione trovata.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SHADER_PARAMETERS,
      "Nessun parametro shader trovato.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OFF,
      "OFF")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ON,
      "ON")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE,
      "Online")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE_UPDATER,
      "Aggiorna Online")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_DISPLAY_SETTINGS,
      "Mostra sullo schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_OVERLAY_SETTINGS,
      "Overlay sullo schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_NOTIFICATIONS_SETTINGS,
      "Notifiche sullo schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPEN_ARCHIVE,
      "Apri archivio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPTIONAL,
      "Opzionale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY,
      "Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_AUTOLOAD_PREFERRED,
      "Autocarica overlay preferito")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_DIRECTORY,
      "Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_OPACITY,
      "Opacità Overlay ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_PRESET,
      "Overlay Predefinito")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SCALE,
      "Scala Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SETTINGS,
      "Overlay sullo schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAL60_ENABLE,
      "Usa modalità PAL60 ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PARENT_DIRECTORY,
      "Directory principale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_LIBRETRO,
      "Pausa quando il menu è attivato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_NONACTIVE,
      "Non eseguire in background")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PERFCNT_ENABLE,
      "Contatori di prestazioni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLISTS_TAB,
      "Playlists")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_DIRECTORY,
      "Playlist")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_SETTINGS,
      "Playlists")
MSG_HASH(MENU_ENUM_LABEL_VALUE_POINTER_ENABLE,
      "Supporto touch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PORT,
      "Porta")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRESENT,
      "Presente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRIVACY_SETTINGS,
      "Privacy")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUIT_RETROARCH,
      "Esci da RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ANALOG,
      "Analogici supportati")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_BBFC_RATING,
      "Classificazione BBFC")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CERO_RATING,
      "Classificazione CERO")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_COOP,
      "Co-op supportato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CRC32,
      "CRC32")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DESCRIPTION,
      "Descrizione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DEVELOPER,
      "Sviluppatore")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_ISSUE,
      "Edge Magazine Issue")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_RATING,
      "Valutazione di Edge Magazine ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_REVIEW,
      "Edge Magazine Review")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ELSPA_RATING,
      "Valutazione ELSPA ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ENHANCEMENT_HW,
      "Miglioramento Hardware")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ESRB_RATING,
      "Valutazione ESRB ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FAMITSU_MAGAZINE_RATING,
      "Valutazione Famitsu Magazine ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FRANCHISE,
      "Franchise")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_GENRE,
      "Genere")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_MD5,
      "MD5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_NAME,
      "Nome")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ORIGIN,
      "Origin")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PEGI_RATING,
      "Valutazione PEGI ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PUBLISHER,
      "Editore")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_MONTH,
      "Mese di uscita")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_YEAR,
      "Anno di uscita")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RUMBLE,
      "Rumble supportato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SERIAL,
      "Seriale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SHA1,
      "SHA1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_START_CONTENT,
      "Avvia il contenuto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_TGDB_RATING,
      "Valutazione TGDB ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REBOOT,
      "Riavvia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_CONFIG_DIRECTORY,
      "Configurazione per la registrazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_OUTPUT_DIRECTORY,
      "Output per la registrazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_SETTINGS,
      "Registrazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_CONFIG,
      "Carica configurazione di registrazione.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_DRIVER,
      "Driver per la registrazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_ENABLE,
      "Abilita Registrazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_PATH,
      "Salva la registrazione di Output come...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_USE_OUTPUT_DIRECTORY,
      "Salva la registrazione di Output nella Directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE,
      "File Remap")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_LOAD,
      "Carica File Remap ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_CORE,
      "Salva Core del file di Remap ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_GAME,
      "Salva il file di Remap del gioco ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_REMOVE_CORE,
      "Cancella il file di Remap del Core ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_REMOVE_GAME,
      "Cancella il file di Remap del gioco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REQUIRED,
      "Richiesto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_CONTENT,
      "Riavvia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_RETROARCH,
      "Riavvia RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME,
      "Riprendi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME_CONTENT,
      "Riprendi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROKEYBOARD,
      "RetroTastiera")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD,
      "RetroPad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD_WITH_ANALOG,
      "RetroPad w/ Analogico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETRO_ACHIEVEMENTS_SETTINGS,
      "Achievements")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_ENABLE,
      "Abilita riavvolgimento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_GRANULARITY,
      "Livello di riavvolgimento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_SETTINGS,
      "Riavvolgimento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_BROWSER_DIRECTORY,
      "File Browser")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_CONFIG_DIRECTORY,
      "Configurazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_SHOW_START_SCREEN,
      "Visualizzazione schermata Start")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RIGHT_ANALOG,
      "Analogico Destro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_FAVORITES,
      "Aggiungi a Preferiti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_FAVORITES_PLAYLIST,
      "Aggiungi a Preferiti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN,
      "Avvia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN_MUSIC,
      "Avvia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAMBA_ENABLE,
      "Abilita SAMBA")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVEFILE_DIRECTORY,
      "Salvare il file")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_INDEX,
      "Indice del salva stato automatico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_LOAD,
      "Carica automaticamente i salvataggi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_SAVE,
      "Salva stato automatico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_DIRECTORY,
      "Salva Stato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_THUMBNAIL_ENABLE,
      "Miniature del Salva stato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG,
      "Salva la configurazione corrente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "Salva gli Override dei core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "Salva gli Override dei giochi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_NEW_CONFIG,
      "Salva la nuova configurazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_STATE,
      "Salva Stato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVING_SETTINGS,
      "Salvataggi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_DIRECTORY,
      "Scansione della Directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_FILE,
      "Scansione dei File")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_THIS_DIRECTORY,
      "<Effettua la scansione di questa directory>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREENSHOT_DIRECTORY,
      "Screenshot")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREEN_RESOLUTION,
      "Risoluzione schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SEARCH,
      "Ricerca")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SECONDS,
      "secondi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS,
      "Impostazioni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS_TAB,
      "Impostazioni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER,
      "Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_APPLY_CHANGES,
      "Applica le modifiche")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_OPTIONS,
      "Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON,
      "Onda")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON_SIMPLIFIED,
      "Onda (semplificata)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SIMPLE_SNOW,
      "Neve semplice")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOW,
      "Neve")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_ADVANCED_SETTINGS,
      "Visualizza impostazioni avanzate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_HIDDEN_FILES,
      "Visualizza cartelle e file nascosti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHUTDOWN,
      "Arresta il sistema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SLOWMOTION_RATIO,
      "Rapporto Slow-Motion ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVEFILES_ENABLE,
      "Ordina il Salvataggio in Cartelle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVESTATES_ENABLE,
      "Ordina i Salvataggi in Cartelle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATES_IN_CONTENT_DIR_ENABLE,
      "Scrivi i salvataggi nella directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVEFILES_IN_CONTENT_DIR_ENABLE,
      "Scrivi il salvataggio nella directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEMFILES_IN_CONTENT_DIR_ENABLE,
      "I file di sistema sono contenuti nella directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREENSHOTS_IN_CONTENT_DIR_ENABLE,
      "Scrivi gli Screenshots contenuti nella directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SSH_ENABLE,
      "Abilita SSH")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_CORE,
      "Avvia Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_NET_RETROPAD,
      "Avvia RetroPad Remoto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_VIDEO_PROCESSOR,
      "Avvia Video Processore")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATE_SLOT,
      "Slot di salvataggio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATUS,
      "Stato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STDIN_CMD_ENABLE,
      "Commandi stdin ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUPPORTED_CORES,
      "Core Suggeriti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUSPEND_SCREENSAVER_ENABLE,
      "Sospendi Screensaver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_BGM_ENABLE,
      "Abilita Sistema BGM ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_DIRECTORY,
      "Sistema/BIOS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFORMATION,
      "Informazioni di sistema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_7ZIP_SUPPORT,
      "Supporto 7zip")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ALSA_SUPPORT,
      "Supporto ALSA")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_BUILD_DATE,
      "Data di costruzione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CG_SUPPORT,
      "Supporto Cg")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COCOA_SUPPORT,
      "Supporto Cocoa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COMMAND_IFACE_SUPPORT,
      "Supporto interfaccia di comando")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CORETEXT_SUPPORT,
      "Supporto CoreText")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CPU_FEATURES,
      "Caratteristiche CPU ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_DPI,
      "Visualizza DPI metrica")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_HEIGHT,
      "Visualizza l'altezza metrica (mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_WIDTH,
      "Visualizza la larghezza metrica (mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DSOUND_SUPPORT,
      "Supporto DirectSound ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WASAPI_SUPPORT,
      "Supporto WASAPI ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYLIB_SUPPORT,
      "Supporto libreria Dinamica  ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYNAMIC_SUPPORT,
      "Caricamento run-time dinamico della libreria libretro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_EGL_SUPPORT,
      "Supporto EGL ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FBO_SUPPORT,
      "Supporto render-to-texture (multi-pass shaders) OpenGL/Direct3D")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FFMPEG_SUPPORT,
      "Supporto FFmpeg ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FREETYPE_SUPPORT,
      "Supporto FreeType ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_IDENTIFIER,
      "Identificatore frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_NAME,
      "Nome frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_OS,
      "Frontend OS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GIT_VERSION,
      "Versione Git")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GLSL_SUPPORT,
      "Supporto GLSL ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_HLSL_SUPPORT,
      "Supporto HLSL ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_JACK_SUPPORT,
      "Supporto JACK ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_KMS_SUPPORT,
      "Supporto KMS/EGL ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LAKKA_VERSION,
      "Versione Lakka")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBRETRODB_SUPPORT,
      "Supporto LibretroDB ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBUSB_SUPPORT,
      "Supporto Libusb ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBXML2_SUPPORT,
      "Supporto libxml2 XML parsing ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETPLAY_SUPPORT,
      "Supporto Netplay (peer-to-peer) ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_COMMAND_IFACE_SUPPORT,
      "Supporto dell'interfaccia di comando di rete")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_REMOTE_SUPPORT,
      "Supporto Gamepad di rete")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENAL_SUPPORT,
      "Supporto OpenAL ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGLES_SUPPORT,
      "Suppporto OpenGL ES ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGL_SUPPORT,
      "Supporto OpenGL ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENSL_SUPPORT,
      "Supporto OpenSL ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENVG_SUPPORT,
      "Supporto OpenVG ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OSS_SUPPORT,
      "Supporto OSS ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OVERLAY_SUPPORT,
      "Supporto Overlay ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE,
      "Fonte di alimentazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGED,
      "Caricato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGING,
      "Caricamento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_DISCHARGING,
      "Scaricamento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_NO_SOURCE,
      "Nessuna fonte")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PULSEAUDIO_SUPPORT,
      "Supporto PulseAudio ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PYTHON_SUPPORT,
      "Supporto Python (script support in shaders) ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RBMP_SUPPORT,
      "Supporto BMP (RBMP)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RETRORATING_LEVEL,
      "Livello RetroRating ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RJPEG_SUPPORT,
      "Supporto JPEG (RJPEG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ROARAUDIO_SUPPORT,
      "Supporto RoarAudio ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RPNG_SUPPORT,
      "Supporto PNG (RPNG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RSOUND_SUPPORT,
      "Supporto RSound ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RTGA_SUPPORT,
      "Supporto TGA (RTGA)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL2_SUPPORT,
      "Supporto SDL2 ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_IMAGE_SUPPORT,
      "Supporto immagine SDL ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_SUPPORT,
      "Supporto SDL1.2 ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SLANG_SUPPORT,
      "Supporto Slang ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_THREADING_SUPPORT,
      "Supporto Threading ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_UDEV_SUPPORT,
      "Supporto Udev ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_V4L2_SUPPORT,
      "Supporto Video4Linux2 ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VIDEO_CONTEXT_DRIVER,
      "Video context driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VULKAN_SUPPORT,
      "Supporto Vulkan ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WAYLAND_SUPPORT,
      "Supporto Wayland ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_X11_SUPPORT,
      "Supporto X11 ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XAUDIO2_SUPPORT,
      "Supporto XAudio2 ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XVIDEO_SUPPORT,
      "Supporto XVideo ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ZLIB_SUPPORT,
      "Supporto Zlib ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TAKE_SCREENSHOT,
      "Effettua Screenshot")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THREADED_DATA_RUNLOOP_ENABLE,
      "Threaded tasks")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS,
      "Miniature")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_DIRECTORY,
      "Miniature")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_UPDATER_LIST,
      "Aggiorna Miniature")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_BOXARTS,
      "Boxarts")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_SCREENSHOTS,
      "Screenshots")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_TITLE_SCREENS,
      "Title Screens")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TIMEDATE_ENABLE,
      "Visualizza data / ora")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TITLE_COLOR,
      "Colore titolo del Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TRUE,
      "Vero")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_ENABLE,
      "Abilita UI Companion")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_START_ON_BOOT,
      "Abilita UI Companion all'avvio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_MENUBAR_ENABLE,
      "Menubar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNABLE_TO_READ_COMPRESSED_FILE,
      "Impossibile leggere il file compresso.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_LOAD_STATE,
      "Annulla carica stato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_SAVE_STATE,
      "Annulla salva stato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNKNOWN,
      "Sconosciuto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATER_SETTINGS,
      "Aggiornamento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_ASSETS,
      "Aggiorna risorse")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_AUTOCONFIG_PROFILES,
      "Aggiorna i profili del Joypad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CG_SHADERS,
      "Aggiorna Cg Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CHEATS,
      "Aggiorna Cheats")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CORE_INFO_FILES,
      "Aggiona i file di informazione del Core ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_DATABASES,
      "Aggiorna i Database")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_GLSL_SHADERS,
      "Aggiorna GLSL Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_LAKKA,
      "Aggiorna Lakka")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_OVERLAYS,
      "Aggiorna gli Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_SLANG_SHADERS,
      "Aggiorna Slang Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER,
      "Utente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_INTERFACE_SETTINGS,
      "Interfaccia utente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_LANGUAGE,
      "Linguaggio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_SETTINGS,
      "Utente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_IMAGE_VIEWER,
      "Utilizza Visualizzatore immagini integrato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_PLAYER,
      "Use Media Player integrato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_THIS_DIRECTORY,
      "<Usa questa directory>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ALLOW_ROTATE,
      "Consenti la rotazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO,
      "Configura Rapporto d'aspetto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_AUTO,
      "Rapporto d'aspetto Automatico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_INDEX,
      "Rapporto d'aspetto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_BLACK_FRAME_INSERTION,
      "Inserimento Frame nero")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_CROP_OVERSCAN,
      "Crop Overscan (Ricarica)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DISABLE_COMPOSITION,
      "Disattiva composizione del Desktop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DRIVER,
      "Driver Video")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER,
      "Filtro Video")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_DIR,
      "Filtro Video ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_FLICKER,
      "Filtro sfarfallio ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_ENABLE,
      "Abilita le notifiche sullo schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_PATH,
      "Font delle notifiche su schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_SIZE,
      "Dimensioni delle notifiche su schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_ASPECT,
      "Forza Rapporto d'aspetto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_SRGB_DISABLE,
      "Forza-disabilita sRGB FBO")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FRAME_DELAY,
      "Ritardo del Frame ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN,
      "Utilizza la modalità a schermo intero")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GAMMA,
      "Video Gamma")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_RECORD,
      "Utilizza la registrazione da GPU ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_SCREENSHOT,
      "Abilita Screenshot da GPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC,
      "Sincronizzazione GPU forzata")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC_FRAMES,
      "Sincronizzazione dei fotogrammi della GPU forzata")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "Massimo swapchain di immagini")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_X,
      "Posizione X delle notifiche su schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_Y,
      "Posizione Y delle notifiche su schermo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MONITOR_INDEX,
      "Indice del monitor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_POST_FILTER_RECORD,
      "Utilizza registrazione Post Filtro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE,
      "Frequenza di aggiornamento verticale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_AUTO,
      "Framerate dello schermo stimato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_POLLED,
      "Set Display-Reported Refresh Rate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ROTATION,
      "Rotazione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE,
      "Scala con finestra")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE_INTEGER,
      "Scala Integer ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SETTINGS,
      "Video")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_DIR,
      "Video Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_NUM_PASSES,
      "Shader Passes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PARAMETERS,
      "Anteprima dei parametri Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET,
      "Carica Shader Preset")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_AS,
      "Salvare Preset Shader come")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_CORE,
      "Salva Core Preset")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_GAME,
      "Salva Game Preset")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHARED_CONTEXT,
      "Abilita il contesto condiviso Hardware")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SMOOTH,
      "Filtro Bilineare")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SOFT_FILTER,
      "Abilita il filtro morbido ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SWAP_INTERVAL,
      "Vertical Sync (Vsync) Swap Interval")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_TAB,
      "Video")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_THREADED,
      "Threaded Video")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VFILTER,
      "Deflicker")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "Personalizza Rapporto d'aspetto in Altezza")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "Personalizza Rapporto d'aspetto in Larghezza")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_X,
      "Personalizza Rapporto d'aspetto in una posizione X.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_Y,
      "Personalizza Rapporto d'aspetto in una posizione Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VI_WIDTH,
      "Impostare la larghezza dello schermo VI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VSYNC,
      "Sincronizzazione verticale (Vsync)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOWED_FULLSCREEN,
      "Modalità finestra a schermo intero")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_WIDTH,
      "Larghezza della finestra")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_HEIGHT,
      "Altezza della finestra")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN_X,
      "Larghezza a schermo intero")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN_Y,
      "Altezza a schermo intero")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_DRIVER,
      "Driver Wi-Fi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_SETTINGS,
      "Wi-Fi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ALPHA_FACTOR,
      "Menu del fattore Alfa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_RED,
      "Font del Menu di colore Rosso")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_GREEN,
      "Font del Menu di colore Verde")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_BLUE,
      "Font del Menu di colore Blue")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_FONT,
      "Font del Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_CUSTOM,
      "Personalizzato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_FLATUI,
      "FlatUI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME,
      "Monocromatico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME_INVERTED,
      "Monocromatico Rovesciato")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_SYSTEMATIC,
      "Sistematico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_NEOACTIVE,
      "NeoAttivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_PIXEL,
      "Pixel")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROACTIVE,
      "RetroAttivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROSYSTEM,
      "Retrosystem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_DOTART,
      "Dot-Art")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME,
      "Colore del menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_APPLE_GREEN,
      "Mela Verde")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK,
      "Scuro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK_PURPLE,
      "Viola Scuro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_ELECTRIC_BLUE,
      "Blu Elettrico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_GOLDEN,
      "Oro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LEGACY_RED,
      "Rosso Legacy ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_MIDNIGHT_BLUE,
      "Blu notte")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_PLAIN,
      "Pianura")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_UNDERSEA,
      "Sottomarino")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_VOLCANIC_RED,
      "Rosso vulcanico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_RIBBON_ENABLE,
      "Menu Shader Pipeline")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SCALE_FACTOR,
      "Menu Scale Factor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SHADOWS_ENABLE,
      "Abilita Ombre delle Icone")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_HISTORY,
      "Visualizza la colonna cronologia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_ADD,
      "Visualizza colonna Importa contenuto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_FAVORITES,
      "Visualizza colonna Preferiti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_IMAGES,
      "Visualizza colonna Immagini")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_MUSIC,
      "Visualizza colonna Musica")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS,
      "Visualizza colonna Impostazioni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_VIDEO,
      "Visualizza colonna Video")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_NETPLAY,
      "Visualizza colonna Stanze Netplay ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_LAYOUT,
      "Menu Layout")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_THEME,
      "Icone del Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_YES,
      "Si")
MSG_HASH(MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_TWO,
      "Shader Preset")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_ENABLE,
      "Abilita o disabilita achievements. Per maggiori informazioni, visitate il sito http://retroachievements.org")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_TEST_UNOFFICIAL,
      "Abilita o disabilita gli achievements non ufficiali e/o funzionalità beta per scopi di test.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Abilita o disabilita i salvataggi,cheats,la funzione riavvolgimento, avanzamento rapido, pausa, e slow-motion per tutti i giochi.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_VERBOSE_ENABLE,
      "Abilita o disabilita OSD verbosity per gli achievements.")
MSG_HASH(MENU_ENUM_SUBLABEL_DRIVER_SETTINGS,
      "Modifica i driver utilizzati dal sistema.")
MSG_HASH(MENU_ENUM_SUBLABEL_RETRO_ACHIEVEMENTS_SETTINGS,
      "Modifica le impostazioni degli achievement .")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_SETTINGS,
      "Modifica le impostazioni dei core .")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_SETTINGS,
      "Modifica le impostazioni di registrazione.")
MSG_HASH(MENU_ENUM_SUBLABEL_ONSCREEN_DISPLAY_SETTINGS,
      "Modifica le impostazioni per l'overlay del display, l'overlay della tastiera e le notifiche dello schermo.")
MSG_HASH(MENU_ENUM_SUBLABEL_FRAME_THROTTLE_SETTINGS,
      "Modifica le impostazioni per il riavvolgimento, avanzamento rapido e slow-motion")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVING_SETTINGS,
      "Modifica le impostazioni per i salvataggi")
MSG_HASH(MENU_ENUM_SUBLABEL_LOGGING_SETTINGS,
      "Modifica le impostazioni per il login.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_INTERFACE_SETTINGS,
      "Modifica le impostazioni per l'interfaccia utente.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_SETTINGS,
      "Modifica accounts, nome utente, e linguaggio.")
MSG_HASH(MENU_ENUM_SUBLABEL_PRIVACY_SETTINGS,
      "Modifica le tue impostazioni della privacy.")
MSG_HASH(MENU_ENUM_SUBLABEL_DIRECTORY_SETTINGS,
      "Modifica le directory predefinite per questo sistema.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_SETTINGS,
      "Modifica le impostazioni della playlists.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_SETTINGS,
      "Configura il server e le impostazioni di rete.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_CONTENT_LIST,
      "Effettua la scansione del contenuto e li aggiunge al database.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_SETTINGS,
      "Modifica le impostazioni per l'uscita audio.")
MSG_HASH(MENU_ENUM_SUBLABEL_BLUETOOTH_ENABLE,
      "Abilita o disabilita il bluetooth.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIG_SAVE_ON_EXIT,
      "Salva le modifiche al file di configurazione all'uscita del programma.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATION_SETTINGS,
      "Modifica le impostazioni predefinite per i file di configurazione.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATIONS_LIST,
      "Gestione e creazione di file di configurazione.")
MSG_HASH(MENU_ENUM_SUBLABEL_CPU_CORES,
      "Quantità di core che la CPU possiede.")
MSG_HASH(MENU_ENUM_SUBLABEL_FPS_SHOW,
      "Consente di visualizzare la frequenza dei fotogrammi corrente al secondo sullo schermo.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_HOTKEY_BINDS,
      "Configura le impostazioni hotkey ")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "Combinazioni dei pulsanti del Gamepad per attivare il menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_SETTINGS,
      "Modifica le impostazioni per joypad, tastiera e mouse")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_USER_BINDS,
      "Configura i controlli per questo utente.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOG_VERBOSITY,
      "Abilita o disabilita la registrazione al terminale.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY,
      "Unisci o ospita una sessione di netplay.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_LAN_SCAN_SETTINGS,
      "Ricerca e connetti all' host netplay sulla rete locale.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION_LIST_LIST,
      "Visualizza le informazioni dei core, di rete e di sistema.")
MSG_HASH(MENU_ENUM_SUBLABEL_ONLINE_UPDATER,
      "Scarica add-ons, componenti, e contenuti per RetroArch.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAMBA_ENABLE,
      "Attiva o disattiva la condivisione di rete delle tue cartelle")
MSG_HASH(MENU_ENUM_SUBLABEL_SERVICES_SETTINGS,
      "Gestire i servizi del livello di sistema operativo.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_HIDDEN_FILES,
      "Mostra file / directory nascoste all'interno del file browser.")
MSG_HASH(MENU_ENUM_SUBLABEL_SSH_ENABLE,
      "Abilita o disabilita l'accesso alla riga di comando remota.")
MSG_HASH(MENU_ENUM_SUBLABEL_SUSPEND_SCREENSAVER_ENABLE,
      "Impedisce che lo screensaver del tuo sistema diventi attivo.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_SCALE,
      "Imposta la dimensione della finestra rispetto alla dimensione principale della vista. In alternativa, puoi impostare una larghezza e un'altezza della finestra sotto ,con una dimensione della finestra fissa")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_LANGUAGE,
      "Imposta la lingua dell'interfaccia.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_BLACK_FRAME_INSERTION,
      "Inserisce una cornice nera tra i fotogrammi. Utile per gli utenti che hanno schermi da 120 Hz e vogliono riprodurre il materiale da 60 Hz con l' eliminazione dell'effetto ghosting.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FRAME_DELAY,
      "Riduce la latenza a costo di un più alto rischio di sfarfallio video. Aggiunge un ritardo dopo V-Sync (in ms).")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC_FRAMES,
      "Imposta quanti frame la CPU può eseguire dinanzi alla GPU quando utilizza 'Hard GPU Sync'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "Indica al driver video di utilizzare esplicitamente una modalità di buffering specifica.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MONITOR_INDEX,
      "Seleziona lo schermo da utilizzare.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_AUTO,
      "La stima precisa di aggiornamento dello schermo in Hz.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_POLLED,
      "The refresh rate as reported by the display driver.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SETTINGS,
      "Cambia le impostazioni per l'uscita video.")
MSG_HASH(MENU_ENUM_SUBLABEL_WIFI_SETTINGS,
      "Effettua una scansione delle reti wireless e stabilisce la connessione.")
MSG_HASH(MENU_ENUM_SUBLABEL_HELP_LIST,
      "Ulteriori informazioni su come funziona il programma.")
MSG_HASH(MSG_ADDED_TO_FAVORITES,
      "Aggiunto ai Preferiti")
MSG_HASH(MSG_APPENDED_DISK,
      "Disco aggiunto")
MSG_HASH(MSG_APPLICATION_DIR,
      "Applicazione in corso della Directory")
MSG_HASH(MSG_APPLYING_CHEAT,
      "Applicazione dei trucchi/cheat in corso")
MSG_HASH(MSG_APPLYING_SHADER,
      "Applicazione dello shader in corso")
MSG_HASH(MSG_AUDIO_MUTED,
      "Audio disattivato.")
MSG_HASH(MSG_AUDIO_UNMUTED,
      "Audio attivato.")
MSG_HASH(MSG_AUTOCONFIG_FILE_ERROR_SAVING,
      "Errore durante il salvataggio del file autoconf.")
MSG_HASH(MSG_AUTOCONFIG_FILE_SAVED_SUCCESSFULLY,
      "Il file di autoconfigurazione è stato salvato correttamente.")
MSG_HASH(MSG_AUTOSAVE_FAILED,
      "Impossibile inizializzare il salvataggio automatico.")
MSG_HASH(MSG_AUTO_SAVE_STATE_TO,
      "Salva stato automatico su")
MSG_HASH(MSG_BLOCKING_SRAM_OVERWRITE,
      "Bloccare la sovrascrittura della SRAM")
MSG_HASH(MSG_BRINGING_UP_COMMAND_INTERFACE_ON_PORT,
      "Bringing up command interface on port")
MSG_HASH(MSG_BYTES,
      "bytes")
MSG_HASH(MSG_CANNOT_INFER_NEW_CONFIG_PATH,
      "Impossibile trovare il nuovo percorso di configurazione. Verrà utilizzato quello corrente .")
MSG_HASH(MSG_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Abilita la modalità hardcore.I salvataggi e la funzione riavvolgimento sono stati disattivati.")
MSG_HASH(MSG_COMPARING_WITH_KNOWN_MAGIC_NUMBERS,
      "Confronto in corso con i numeri magici conosciuti...")
MSG_HASH(MSG_COMPILED_AGAINST_API,
      "Compilate con API")
MSG_HASH(MSG_CONFIG_DIRECTORY_NOT_SET,
      "Non è stata impostata nessuna directory per la configurazione. Non è possibile salvare la nuova configurazione.")
MSG_HASH(MSG_CONNECTED_TO,
      "Collegato a")
MSG_HASH(MSG_CONTENT_CRC32S_DIFFER,
      "Contenuti CRC32 differenti. Non è possibile utilizzare diversi giochi.")
MSG_HASH(MSG_CONTENT_LOADING_SKIPPED_IMPLEMENTATION_WILL_DO_IT,
      "Il caricamento del contenuto è stato saltato.Le Implemenzioni verranno caricati in proprio.")
MSG_HASH(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES,
      "Il Core non supporta gli salva stati.")
MSG_HASH(MSG_CORE_OPTIONS_FILE_CREATED_SUCCESSFULLY,
      "Il file delle opzioni dei core è stato creato correttamente.")
MSG_HASH(MSG_COULD_NOT_FIND_ANY_NEXT_DRIVER,
      "Impossibile trovare un altro driver successivo")
MSG_HASH(MSG_COULD_NOT_FIND_COMPATIBLE_SYSTEM,
      "Impossibile trovare un sistema compatibile.")
MSG_HASH(MSG_COULD_NOT_FIND_VALID_DATA_TRACK,
      "Impossibile trovare una traccia di dati valida")
MSG_HASH(MSG_COULD_NOT_OPEN_DATA_TRACK,
      "Impossibile aprire la traccia dati")
MSG_HASH(MSG_COULD_NOT_READ_CONTENT_FILE,
      "Impossibile leggere il contenuto del file")
MSG_HASH(MSG_COULD_NOT_READ_MOVIE_HEADER,
      "Impossibile leggere l'intestazione del filmato.")
MSG_HASH(MSG_COULD_NOT_READ_STATE_FROM_MOVIE,
      "Impossibile leggere lo stato dal filmato.")
MSG_HASH(MSG_CRC32_CHECKSUM_MISMATCH,
      "La mancata corrispondenza del checksum CRC32 tra il file di contenuto e il checksum del contenuto salvato nell'intestazione del file di replay, riproduce molto probabilmente il desync sulla riproduzione.")
MSG_HASH(MSG_CUSTOM_TIMING_GIVEN,
      "Custom timing given")
MSG_HASH(MSG_DECOMPRESSION_ALREADY_IN_PROGRESS,
      "Decompressione già in corso.")
MSG_HASH(MSG_DECOMPRESSION_FAILED,
      "La decompressione non è riuscita.")
MSG_HASH(MSG_DETECTED_VIEWPORT_OF,
      "Rilevati i viewport di")
MSG_HASH(MSG_DID_NOT_FIND_A_VALID_CONTENT_PATCH,
      "Non è stata trovata una patch di contenuto valida.")
MSG_HASH(MSG_DISCONNECT_DEVICE_FROM_A_VALID_PORT,
      "Disconnessione del dispositivo da una porta valida")
MSG_HASH(MSG_DISK_CLOSED,
      "Chiuso")
MSG_HASH(MSG_DISK_EJECTED,
      "Espulsione")
MSG_HASH(MSG_DOWNLOADING,
      "Scaricamento in corso del file")
MSG_HASH(MSG_DOWNLOAD_FAILED,
      "Download fallito")
MSG_HASH(MSG_ERROR,
      "Errore")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_CONTENT,
      "Il core Libretro richiede contenuti, ma nessun dato è stato fornito..")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_SPECIAL_CONTENT,
      "I core Libretro richiedono contenuti speciali, ma nessun dato è stato fornito.")
MSG_HASH(MSG_ERROR_PARSING_ARGUMENTS,
      "Errore durante l'analisi di argomenti.")
MSG_HASH(MSG_ERROR_SAVING_CORE_OPTIONS_FILE,
      "Errore nel salvataggio del file delle opzioni del core.")
MSG_HASH(MSG_ERROR_SAVING_REMAP_FILE,
      "Errore nel salvataggio del file remap.")
MSG_HASH(MSG_ERROR_REMOVING_REMAP_FILE,
      "Errore durante la rimozione del file remap.")
MSG_HASH(MSG_ERROR_SAVING_SHADER_PRESET,
      "Errore durante il salvataggio delle preimpostazioni di shader.")
MSG_HASH(MSG_EXTERNAL_APPLICATION_DIR,
      "Directory dell'applicazione esterna")
MSG_HASH(MSG_EXTRACTING,
      "Estrazione in corso del file")
MSG_HASH(MSG_EXTRACTING_FILE,
      "Estrazione del file")
MSG_HASH(MSG_FAILED_SAVING_CONFIG_TO,
      "Non è riuscito il salvataggio della configurazione per")
MSG_HASH(MSG_FAILED_TO,
      "Non è riuscito a")
MSG_HASH(MSG_FAILED_TO_ACCEPT_INCOMING_SPECTATOR,
      "Impossibile accettare lo spettatore.")
MSG_HASH(MSG_FAILED_TO_ALLOCATE_MEMORY_FOR_PATCHED_CONTENT,
      "Impossibile allocare la memoria per il contenuto patchato...")
MSG_HASH(MSG_FAILED_TO_APPLY_SHADER,
      "Impossibile applicare lo shader.")
MSG_HASH(MSG_FAILED_TO_BIND_SOCKET,
      "Impossibile collegare il socket.")
MSG_HASH(MSG_FAILED_TO_CREATE_THE_DIRECTORY,
      "Impossibile creare la directory")
MSG_HASH(MSG_FAILED_TO_EXTRACT_CONTENT_FROM_COMPRESSED_FILE,
      "Impossibile estrarre il contenuto dal file compresso")
MSG_HASH(MSG_FAILED_TO_GET_NICKNAME_FROM_CLIENT,
      "Impossibile ottenere il nome utente dal client.")
MSG_HASH(MSG_FAILED_TO_LOAD,
      "Caricamento fallito")
MSG_HASH(MSG_FAILED_TO_LOAD_CONTENT,
      "Impossibile caricare il contenuto")
MSG_HASH(MSG_FAILED_TO_LOAD_MOVIE_FILE,
      "Impossibile caricare il file del filmato")
MSG_HASH(MSG_FAILED_TO_LOAD_OVERLAY,
      "Impossibile caricare l'overlay.")
MSG_HASH(MSG_FAILED_TO_LOAD_STATE,
      "Impossibile caricare lo stato da")
MSG_HASH(MSG_FAILED_TO_OPEN_LIBRETRO_CORE,
      "Impossibile aprire il core libretro ")
MSG_HASH(MSG_FAILED_TO_PATCH,
      "Non è riuscito a patchare")
MSG_HASH(MSG_FAILED_TO_RECEIVE_HEADER_FROM_CLIENT,
      "Impossibile ricevere intestazione dal client.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME,
      "Impossibile ricevere il nome utente.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_FROM_HOST,
      "Impossibile ricevere il nome utente dall'host")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_SIZE_FROM_HOST,
      "Impossibile ricevere la dimensione del nome utente dall'host.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_SRAM_DATA_FROM_HOST,
      "Impossibile ricevere dati SRAM dall'host.")
MSG_HASH(MSG_FAILED_TO_REMOVE_DISK_FROM_TRAY,
      "Impossibile rimuovere il disco dal vassoio.")
MSG_HASH(MSG_FAILED_TO_REMOVE_TEMPORARY_FILE,
      "Impossibile rimuovere il file temporaneo")
MSG_HASH(MSG_FAILED_TO_SAVE_SRAM,
      "Impossibile salvare la SRAM")
MSG_HASH(MSG_FAILED_TO_SAVE_STATE_TO,
      "Impossibile salvare lo stato")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME,
      "Impossibile inviare il nome utente.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_SIZE,
      "Impossibile inviare la dimensione del nome utente.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_CLIENT,
      "Impossibile inviare il nome utente al client.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_HOST,
      "Impossibile inviare il nome utente all' host.")
MSG_HASH(MSG_FAILED_TO_SEND_SRAM_DATA_TO_CLIENT,
      "Impossibile inviare i dati SRAM al client.")
MSG_HASH(MSG_FAILED_TO_START_AUDIO_DRIVER,
      "Impossibile avviare il driver audio.Il contenuto continuerà senza audio.")
MSG_HASH(MSG_FAILED_TO_START_MOVIE_RECORD,
      "Impossibile avviare la registrazione del film")
MSG_HASH(MSG_FAILED_TO_START_RECORDING,
      "Impossibile avviare la registrazione.")
MSG_HASH(MSG_FAILED_TO_TAKE_SCREENSHOT,
      "Impossibile eseguire lo screenshot.")
MSG_HASH(MSG_FAILED_TO_UNDO_LOAD_STATE,
      "Impossibile annullare il caricamento dello stato .")
MSG_HASH(MSG_FAILED_TO_UNDO_SAVE_STATE,
      "Impossibile annullare il salvataggio.")
MSG_HASH(MSG_FAILED_TO_UNMUTE_AUDIO,
      "Impossibile disattivare l'audio.")
MSG_HASH(MSG_FATAL_ERROR_RECEIVED_IN,
      "Errore irreversibile ricevuto in")
MSG_HASH(MSG_FILE_NOT_FOUND,
      "File non trovato")
MSG_HASH(MSG_FOUND_AUTO_SAVESTATE_IN,
      "Trovato salva stato automatico in")
MSG_HASH(MSG_FOUND_DISK_LABEL,
      "Trovata Etichetta del disco ")
MSG_HASH(MSG_FOUND_FIRST_DATA_TRACK_ON_FILE,
      "Trovata la prima traccia dati su file")
MSG_HASH(MSG_FOUND_LAST_STATE_SLOT,
      "Trovato l'ultimo slot di salvataggio")
MSG_HASH(MSG_FOUND_SHADER,
      "Trovato shader")
MSG_HASH(MSG_FRAMES,
      "Frames")
MSG_HASH(MSG_GAME_SPECIFIC_CORE_OPTIONS_FOUND_AT,
      "Opzioni di gioco: opzioni di base specifiche per il gioco trovate in")
MSG_HASH(MSG_GOT_INVALID_DISK_INDEX,
      "Indice del disco non valida.")
MSG_HASH(MSG_GRAB_MOUSE_STATE,
      "Grab mouse state")
MSG_HASH(MSG_GAME_FOCUS_ON,
      "Game focus on")
MSG_HASH(MSG_GAME_FOCUS_OFF,
      "Game focus off")
MSG_HASH(MSG_HW_RENDERED_MUST_USE_POSTSHADED_RECORDING,
      "Libretro core is hardware rendered. Must use post-shaded recording as well.")
MSG_HASH(MSG_INFLATED_CHECKSUM_DID_NOT_MATCH_CRC32,
      "Il checksum inserito non corrisponde a CRC32.")
MSG_HASH(MSG_INPUT_CHEAT,
      "Input Cheat")
MSG_HASH(MSG_INPUT_CHEAT_FILENAME,
      "Immettere il nome del file cheat")
MSG_HASH(MSG_INPUT_PRESET_FILENAME,
      "Nome del file predefinito")
MSG_HASH(MSG_INPUT_RENAME_ENTRY,
      "Rinomina Titolo")
MSG_HASH(MSG_INTERFACE,
      "Interfaccia")
MSG_HASH(MSG_INTERNAL_STORAGE,
      "Archiviazione interna")
MSG_HASH(MSG_REMOVABLE_STORAGE,
      "Spazio di archiviazione rimovibile")
MSG_HASH(MSG_INVALID_NICKNAME_SIZE,
      "Dimensione del nome utente non valido.")
MSG_HASH(MSG_IN_BYTES,
      "in bytes")
MSG_HASH(MSG_IN_GIGABYTES,
      "in gigabytes")
MSG_HASH(MSG_IN_MEGABYTES,
      "in megabytes")
MSG_HASH(MSG_LIBRETRO_ABI_BREAK,
      "è compilato con una versione diversa di libretro di questa implementazione di libretro.")
MSG_HASH(MSG_LIBRETRO_FRONTEND,
      "Frontend per libretro")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT,
      "Caricamento del salvataggio dallo slot #%d.")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT_AUTO,
      "Caricamento del salvataggio dallo slot #-1 (automatico).")
MSG_HASH(MSG_LOADING,
      "Caricamento in corso")
MSG_HASH(MSG_FIRMWARE,
      "Mancano uno o più file del firmware")
MSG_HASH(MSG_LOADING_CONTENT_FILE,
      "Caricamento dei file di contenuto")
MSG_HASH(MSG_LOADING_HISTORY_FILE,
      "Caricamento dei file della cronologia")
MSG_HASH(MSG_LOADING_STATE,
      "Caricamento dello stato")
MSG_HASH(MSG_MEMORY,
      "Memoria")
MSG_HASH(MSG_MOVIE_FILE_IS_NOT_A_VALID_BSV1_FILE,
      "Il File del filmato non è un file valido di BSV1.")
MSG_HASH(MSG_MOVIE_FORMAT_DIFFERENT_SERIALIZER_VERSION,
      "Il formato del film sembra avere una versione di serializzazione diversa. Molto probabilmente non verrà avviato.")
MSG_HASH(MSG_MOVIE_PLAYBACK_ENDED,
      "La riproduzione del film è terminata.")
MSG_HASH(MSG_MOVIE_RECORD_STOPPED,
      "Arresto in corso della registrazione del film.")
MSG_HASH(MSG_NETPLAY_FAILED,
      "Impossibile inizializzare il netplay.")
MSG_HASH(MSG_NO_CONTENT_STARTING_DUMMY_CORE,
      "Nessun contenuto, avvio dummy core.")
MSG_HASH(MSG_NO_SAVE_STATE_HAS_BEEN_OVERWRITTEN_YET,
      "Nessun salvataggio è stato ancora sovrascritto.")
MSG_HASH(MSG_NO_STATE_HAS_BEEN_LOADED_YET,
      "Nessun salvataggio è stato ancora caricato")
MSG_HASH(MSG_OVERRIDES_ERROR_SAVING,
      "Errore durante il salvataggio degli override.")
MSG_HASH(MSG_OVERRIDES_SAVED_SUCCESSFULLY,
      "Override salvati correttamente.")
MSG_HASH(MSG_PAUSED,
      "Pausa.")
MSG_HASH(MSG_PROGRAM,
      "RetroArch")
MSG_HASH(MSG_READING_FIRST_DATA_TRACK,
      "Reading first data track...")
MSG_HASH(MSG_RECEIVED,
      "ricevuto")
MSG_HASH(MSG_RECORDING_TERMINATED_DUE_TO_RESIZE,
      "La registrazione è terminata a causa del ridimensionamento.")
MSG_HASH(MSG_RECORDING_TO,
      "Registrazione su")
MSG_HASH(MSG_REDIRECTING_CHEATFILE_TO,
      "Reindirizzare il file cheat su")
MSG_HASH(MSG_REDIRECTING_SAVEFILE_TO,
      "Reindirizzare il file di salvataggio su")
MSG_HASH(MSG_REDIRECTING_SAVESTATE_TO,
      "Reindirizzare il salva stato su")
MSG_HASH(MSG_REMAP_FILE_SAVED_SUCCESSFULLY,
      "Il file Remap è stato salvato con successo ")
MSG_HASH(MSG_REMAP_FILE_REMOVED_SUCCESSFULLY,
      "Il file Remap è stato rimosso con successo ")
MSG_HASH(MSG_REMOVED_DISK_FROM_TRAY,
      "Rimosso il disco dal vassoio.")
MSG_HASH(MSG_REMOVING_TEMPORARY_CONTENT_FILE,
      "Rimosso un file di contenuto temporaneo")
MSG_HASH(MSG_RESET,
      "Resetta")
MSG_HASH(MSG_RESTARTING_RECORDING_DUE_TO_DRIVER_REINIT,
      "Restarting recording due to driver reinit.")
MSG_HASH(MSG_RESTORED_OLD_SAVE_STATE,
      "Ripristinato un vecchio salva stato.")
MSG_HASH(MSG_RESTORING_DEFAULT_SHADER_PRESET_TO,
      "Shader: ripristino dello shader predefinito preimpostato su")
MSG_HASH(MSG_REVERTING_SAVEFILE_DIRECTORY_TO,
      "Ripristino della directory dei file di salvataggio su")
MSG_HASH(MSG_REVERTING_SAVESTATE_DIRECTORY_TO,
      "Ripristino directory del salva stato su")
MSG_HASH(MSG_REWINDING,
      "Riavvolgimento in corso.")
MSG_HASH(MSG_REWIND_INIT,
      "Inizializzazione del buffer di riavvolgimento con dimensione")
MSG_HASH(MSG_REWIND_INIT_FAILED,
      "Impossibile inizializzare il buffer del riavvolgimento. Il riavvolgimento sarà disabilitato.")
MSG_HASH(MSG_REWIND_INIT_FAILED_THREADED_AUDIO,
      "L'implementazione utilizza il threaded audio. Impossibile utilizzare il riavvolgimento.")
MSG_HASH(MSG_REWIND_REACHED_END,
      "Raggiunto la fine del buffer di riavvolgimento.")
MSG_HASH(MSG_SAVED_NEW_CONFIG_TO,
      "Salvata la nuova configurazione su")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT,
      "Saved state to slot #%d.")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT_AUTO,
      "Saved state to slot #-1 (auto).")
MSG_HASH(MSG_SAVED_SUCCESSFULLY_TO,
      "Salvato con successo su")
MSG_HASH(MSG_SAVING_RAM_TYPE,
      "Saving RAM type")
MSG_HASH(MSG_SAVING_STATE,
      "Salvataggio dello stato")
MSG_HASH(MSG_SCANNING,
      "Scansione in corso")
MSG_HASH(MSG_SCANNING_OF_DIRECTORY_FINISHED,
      "Scansione della directory completata")
MSG_HASH(MSG_SENDING_COMMAND,
      "Invio del comando")
MSG_HASH(MSG_SEVERAL_PATCHES_ARE_EXPLICITLY_DEFINED,
      "Diverse patch sono definite esplicitamente, ignorando tutti...")
MSG_HASH(MSG_SHADER,
      "Shader")
MSG_HASH(MSG_SHADER_PRESET_SAVED_SUCCESSFULLY,
      "Shader predefinito salvato con successo.")
MSG_HASH(MSG_SKIPPING_SRAM_LOAD,
      "Skipping SRAM load.")
MSG_HASH(MSG_SLOW_MOTION,
      "Slow motion.")
MSG_HASH(MSG_FAST_FORWARD,
      "Avanzamento rapido.")
MSG_HASH(MSG_SLOW_MOTION_REWIND,
      "Riavvolgimento lento.")
MSG_HASH(MSG_SRAM_WILL_NOT_BE_SAVED,
      "La SRAM non verrà salvata.")
MSG_HASH(MSG_STARTING_MOVIE_PLAYBACK,
      "Avvia la riproduzione del filmato.")
MSG_HASH(MSG_STARTING_MOVIE_RECORD_TO,
      "Avvio della registrazione del film su")
MSG_HASH(MSG_STATE_SIZE,
      "Dimensione dello stato")
MSG_HASH(MSG_STATE_SLOT,
      "Slot dello stato")
MSG_HASH(MSG_TAKING_SCREENSHOT,
      "Effettua screenshot.")
MSG_HASH(MSG_TO,
      "to")
MSG_HASH(MSG_UNDID_LOAD_STATE,
      "Annullamento del caricamento del salvataggio")
MSG_HASH(MSG_UNDOING_SAVE_STATE,
      "Annullamento del salvataggio")
MSG_HASH(MSG_UNKNOWN,
      "Sconosciuto")
MSG_HASH(MSG_UNPAUSED,
      "Unpaused.")
MSG_HASH(MSG_UNRECOGNIZED_COMMAND,
      "Comando non riconosciuto")
MSG_HASH(MSG_USING_CORE_NAME_FOR_NEW_CONFIG,
      "Utilizzo del nome di un core per la nuova configurazione.")
MSG_HASH(MSG_USING_LIBRETRO_DUMMY_CORE_RECORDING_SKIPPED,
      "Using libretro dummy core. Skipping recording.")
MSG_HASH(MSG_VALUE_CONNECT_DEVICE_FROM_A_VALID_PORT,
      "Collegare il dispositivo a una porta valida.")
MSG_HASH(MSG_VALUE_DISCONNECTING_DEVICE_FROM_PORT,
      "Scollegamento del dispositivo dalla porta")
MSG_HASH(MSG_VALUE_REBOOTING,
      "Riavvio in corso...")
MSG_HASH(MSG_VALUE_SHUTTING_DOWN,
      "Spegnimento in corso...")
MSG_HASH(MSG_VERSION_OF_LIBRETRO_API,
      "Versione delle API di libretro ")
MSG_HASH(MSG_VIEWPORT_SIZE_CALCULATION_FAILED,
      "Il calcolo della dimensione di visualizzazione è fallito! Continuerà ad utilizzare dati grezzi. Questo probabilmente non funzionerà correttamente")
MSG_HASH(MSG_VIRTUAL_DISK_TRAY,
      "Vassoio del disco virtuale.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_LATENCY,
      "Latenza audio desiderata in millisecondi. Potrebbe non essere visualizzato se il driver audio non è in grado di fornire una latenza .")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MUTE,
      "Attiva/disattiva audio.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RATE_CONTROL_DELTA,
      "Aiuta a eliminare le imperfezioni nei tempi durante la sincronizzazione di audio e video. Siate consapevoli che se disattivato, la corretta sincronizzazione è quasi impossibile da ottenere."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_ALLOW,
      "Consente o non consente l'accesso alla fotocamera da core."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_ALLOW,
      "Consente o non consente l'accesso alla posizione dei servizi da core."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_MAX_USERS,
      "Numero massimo di utenti supportati da RetroArch."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_POLL_TYPE_BEHAVIOR,
      "Influisce come il polling degli input che viene fatto all'interno di RetroArch. L'impostazione 'Anticipato' o 'Ritardato' può causare una minore latenza, a seconda della configurazione."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_ALL_USERS_CONTROL_MENU,
      "Consente a qualsiasi utente di controllare il menu. Se disattivato, solo l'utente 1 può controllare il menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_VOLUME,
      "Volume audio (in dB). 0 dB è un volume normale , nessun guadagno applicato."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_WASAPI_EXCLUSIVE_MODE,
      "Consente al driver WASAPI di prendere il controllo esclusivo del dispositivo audio. Se disabilitato, utilizzerà la modalità condivisa ."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_WASAPI_FLOAT_FORMAT,
      "Utilizza il formato del float per il driver WASAPI, se supportato dal dispositivo audio."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_WASAPI_SH_BUFFER_LENGTH,
      "La lunghezza del buffer intermedio (in fotogrammi) quando si utilizza il driver WASAPI in modalità condivisa."
      )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_SYNC,
   "Sincronizza l'audio. Consigliato."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_AXIS_THRESHOLD,
   "Quanto deve essere inclinato un asse durante la pressione di un pulsante."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_BIND_TIMEOUT,
   "Quantità di secondi da attendere fino al prossimo bind."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_TURBO_PERIOD,
   "Descrive il periodo in cui i tasti turbo-abilitati vengono commutati. I numeri sono descritti in fotogrammi."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_DUTY_CYCLE,
   "Descrive quanto tempo dovrebbe essere il periodo di un pulsante turbo-abilitato. I numeri sono descritti in fotogrammi."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_VSYNC,
   "Sincronizza il video di uscita della scheda grafica alla frequenza di aggiornamento dello schermo. Consigliato"
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_ALLOW_ROTATE,
   "Consente ai core di impostare la rotazione. Se disattivato, le richieste di rotazione vengono ignorate. Utile per le impostazioni in cui ruota manualmente lo schermo."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_DUMMY_ON_CORE_SHUTDOWN,
   "Alcuni core potrebbero avere una funzione di arresto. Se abilitato, impedirà al core di arrestare RetroArch. Al contrario, carica un core dummy."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_CHECK_FOR_MISSING_FIRMWARE,
   "Controlla che il firmware richiesto sia presente prima di tentare di caricare il contenuto."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE,
   "Frequenza di aggiornamento verticale dello schermo.Viene utilizzato per calcolare un'adeguata frequenza di ingresso audio. NOTA: questo verrà ignorata se è abilitato 'Threaded Video' ."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_ENABLE,
   "Abilita l'uscita audio."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_MAX_TIMING_SKEW,
   "La variazione massima della frequenza di ingresso audio. Aumentando il valore, è possibile modificare molto velocemente la temporizzazione al costo dell' audio che diventa impreciso (ad esempio, eseguire core PAL in display NTSC)."
   )
MSG_HASH(
   MSG_FAILED,
   "fallito"
   )
MSG_HASH(
   MSG_SUCCEEDED,
   "ha avuto successo"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED,
   "non configurato"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED_FALLBACK,
   "non configurata, utilizza fallback"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST,
   "Elenco dei cursori del database"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DEVELOPER,
   "Database - Filtro : Sviluppatore"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PUBLISHER,
   "Database - Filtro : Editore"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DISABLED,
   "Disabilitato"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_ENABLED,
   "Abilitato"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_PATH,
   "Storia dei percorsi e dei contenuti"
   )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ORIGIN,
      "Database - Filtro : Origin")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_FRANCHISE,
      "Database - Filtro : Franchise")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ESRB_RATING,
      "Database - Filtro : Valutazione ESRB ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ELSPA_RATING,
      "Database - Filtro : Valutazione ELSPA ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PEGI_RATING,
      "Database - Filtro : Valutazione PEGI ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_CERO_RATING,
      "Database - Filtro : Valutazione CERO ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_BBFC_RATING,
      "Database - Filtro : Valutazione BBFC ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_MAX_USERS,
      "Database - Filtro : Massimo numero di utenti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_MONTH,
      "Database - Filtro : Releasedate By Month")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_YEAR,
      "Database - Filtro : Releasedate By Year")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_ISSUE,
      "Database - Filtro : Edge Magazine Issue")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_RATING,
      "Database - Filtro : Valutazione Edge Magazine ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DATABASE_INFO,
      "Informazione del Database ")
MSG_HASH(MSG_WIFI_SCAN_COMPLETE,
      "Scansione completata delle reti Wi-Fi .")
MSG_HASH(MSG_SCANNING_WIRELESS_NETWORKS,
      "Scansione delle reti wireless in corso...")
MSG_HASH(MSG_NETPLAY_LAN_SCAN_COMPLETE,
      "Scansione completata delle camere Netplay .")
MSG_HASH(MSG_NETPLAY_LAN_SCANNING,
      "Scansione hosts netplay in corso...")
MSG_HASH(MENU_ENUM_SUBLABEL_PAUSE_NONACTIVE,
      "Sospende il gioco quando RetroArch non ha una finestra attiva.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_DISABLE_COMPOSITION,
      "Attiva o disattiva la composizione (solo Windows).")
MSG_HASH(MENU_ENUM_SUBLABEL_HISTORY_LIST_ENABLE,
      "Abilita o disabilita la playlist recente per giochi, immagini, musica e video.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_HISTORY_SIZE,
      "Limita il numero di voci nella playlist recente per giochi, immagini, musica e video.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_UNIFIED_MENU_CONTROLS,
      "Controlli del Menu Unificati")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_UNIFIED_MENU_CONTROLS,
      "Utilizzare gli stessi controlli per il menu e il gioco. Si applica alla tastiera.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_ENABLE,
      "Visualizza i messaggi sullo schermo.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_USER_REMOTE_ENABLE,
      "Abilita Utente %d da remoto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_BATTERY_LEVEL_ENABLE,
      "Visualizza il livello della batteria")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FILE,
      "Seleziona File")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FROM_COLLECTION,
      "Seleziona da collezione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER,
      "Filtra")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCALE,
      "Scala")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_WHEN_LOADED,
      "Il Netplay verrà avviato quando il contenuto sarà caricato.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LOAD_CONTENT_MANUALLY,
      "Non è possibile trovare un core o un file di contenuto adatto, caricare manualmente.")
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL_LIST,
      "Browse URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL,
      "URL Path"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_START,
      "Avvia"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_BOKEH,
      "Bokeh")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REFRESH_ROOMS,
      "Aggiorna la lista delle camere")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME,
      "Nickname: %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME_LAN,
      "Nickname (lan): %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_COMPAT_CONTENT_FOUND,
      "Contenuto compatibile trovato")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_CROP_OVERSCAN,
      "Taglia alcuni pixel intorno ai bordi dell'immagine generalmente lasciati vuoti dagli sviluppatori che a volte contengono anche i pixel che non vengono utilizzati.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SMOOTH,
      "Aggiunge una leggera sfocatura dell'immagine per togliere il bordo del pixel. Questa opzione ha un piccolo impatto sulle prestazioni.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FILTER,
      "Applica un filtro video, aumentando la potenza della CPU. NOTA: Potrebbe avere un costo sul rendimento. Alcuni filtri video potrebbero funzionare solo per i core che utilizzano un colore a 32 bit o 16 bit.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_USERNAME,
      "Inserisci il nome utente del tuo account Retro Achievements.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_PASSWORD,
      "Inserisci la password del tuo account Retro Achievements.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_NICKNAME,
      "Inserisci il tuo nome utente qui. Questo sarà utilizzato per le sessioni netplay e altre cose.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_POST_FILTER_RECORD,
      "Cattura l'immagine dopo che vengono applicati i filtri (ma non shader). Il tuo video sarà simile a quello che vedi sul tuo schermo.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_LIST,
      "Seleziona il core da utilizzare.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_CONTENT_LIST,
      "Seleziona il contenuto da avviare.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_INFORMATION,
      "Mostra l'interfaccia di rete e gli indirizzi IP associati.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_INFORMATION,
      "Visualizza le informazioni specifiche per quel dispositivo.")
MSG_HASH(MENU_ENUM_SUBLABEL_QUIT_RETROARCH,
      "Chiude il programma.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_WIDTH,
      "Imposta la dimensione personalizzata della finestra di visualizzazione. Lasciando il valore a 0 tenterà di scalare la finestra il più grande possibile.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_HEIGHT,
      "Imposta le dimensioni dell'altezza personalizzata per la finestra del display. Lasciando il valore a 0 tenterà di scalare la finestra il più grande possibile.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_X,
      "Imposta la dimensione personalizzata della larghezza per la modalità a schermo intero senza finestra. Lasciandolo a 0 utilizzerà la risoluzione del desktop.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_Y,
      "Imposta la dimensione personalizzata dell'altezza per la modalità a schermo intero senza finestra. Lasciandolo a 0 utilizzerà la risoluzione del desktop")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_X,
      "Specifica la posizione personalizzata dell'asse X per il testo sullo schermo.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_Y,
      "Specifica la posizione personalizzata dell'asse Y per il testo sullo schermo.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_SIZE,
      "Specifica la dimensione del carattere in punti.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_HIDE_IN_MENU,
      "Nasconde l'overlay all'interno del menu e verrà mostrata nuovamente all'uscita.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS,
      "Mostra gli input della tastiera/controller sull'overlay tramite lo schermo")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS_PORT,
      "Select the port for the overlay to listen to if Show Inputs On Overlay is enabled.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_COLLECTION_LIST,
      "Qui vengono visualizzati i contenuti scansionati."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SCALE_INTEGER,
      "Permette di scalare solo il video per intero. La dimensione base dipende dalla geometria e dall' Aspect Ratio riportati dal sistema. Se non è impostata l'opzione 'Force Aspect', X / Y sarà scalato indipendentemente."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_SCREENSHOT,
      "Schermata di output del materiale ombreggiato GPU se disponibile."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_ROTATION,
      "Forza una certa rotazione dello schermo. La rotazione sarà impostata dal core ."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FORCE_SRGB_DISABLE,
      "Forza la disattivazione del supporto sRGB FBO. Alcuni driver Intel OpenGL su Windows presentano problemi video se è abilitato sRGB FBO."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN,
      "Avvia a schermo intero. Può essere modificato in fase di runtime."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_WINDOWED_FULLSCREEN,
      "Se è a schermo intero e si preferisce utilizzare una modalità a schermo intero a finestre."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_RECORD,
      "Registra l'output del materiale ombreggiato GPU se disponibile."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_INDEX,
      "Quando si effettua un salvataggio, viene salvato automaticamente l'indice del salvataggio prima di essere salvato. Quando carichi il contenuto, l'indice sarà impostato al valore più alto esistente."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BLOCK_SRAM_OVERWRITE,
      "Blocca il salvataggio della SRAM da sovrascrittura durante il caricamento degli stati di salvataggio. Potenzialmente può portare a buggare i giochi."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_FASTFORWARD_RATIO,
      "La velocità massima in cui il contenuto verrà eseguito quando si utilizza l'avanzamento veloce (ad esempio, 5,0x per 60 fps = 300 fps). Se impostato a 0.0x, il rapporto dell'avanzamneto veloce è illimitato (nessun cap FPS)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SLOWMOTION_RATIO,
      "In slow motion, il contenuto verrà rallentato dal valore specificato / impostato."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_ENABLE,
      "Attiva il riavvolgimento.Richiederà maggiori prestazioni durante il gioco."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_GRANULARITY,
      "Quando si riavvolge un numero definito di fotogrammi, è possibile riavvolgere più fotogrammi alla volta, aumentando la velocità di riavvolgimento."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LIBRETRO_LOG_LEVEL,
      "Imposta il livello di registro per i core. Se un livello di registro emesso da un core è inferiore a questo valore, verrà ignorato."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PERFCNT_ENABLE,
      "Abilita i contatori delle prestazioni per RetroArch (e core)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_SAVE,
      "Esegue automaticamente un salvataggio alla fine del runtime di RetroArch. RetroArch caricherà automaticamente questo salvataggio se è abilitato 'Carica automaticamente i Salvataggi'."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_LOAD,
      "Carica automaticamente i salvataggi all'avvio."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_THUMBNAIL_ENABLE,
      "Visualizza le miniature degli stati di salvataggio all'interno del menu"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTOSAVE_INTERVAL,
      "Salva automaticamente la memoria RAM non volatile ad un intervallo regolare. Questa impostazione è disabilitata per impostazione predefinita, L'intervallo è misurato in secondi. Un valore 0 disabilita il salvataggio automatico."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_REMAP_BINDS_ENABLE,
      "Se abilitato, gli input dell'override si legano con i bind rimappati impostati per il core corrente"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_AUTODETECT_ENABLE,
      "Attiva il rilevamento automatico degli input. Tenterà di autoconfigurare i joypad,stile Plug-and-Play ."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_INPUT_SWAP_OK_CANCEL,
      "Scambia i pulsanti OK / Annulla. Disabilitato è l'orientamento per gli utenti giapponesi, abilitato è l'orientamento per gli utenti occidentali."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PAUSE_LIBRETRO,
      "Se disattivato, il contenuto continuerà a funzionare in background quando il menu di RetroArch è attivato."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_DRIVER,
      "Indica il driver video utilizzato."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DRIVER,
      "Indica il driver audio utilizzato."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_DRIVER,
      "Indica il Driver di input utilizzato. A seconda del driver video, potrebbe forzare un diverso driver di input."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_JOYPAD_DRIVER,
      "Indica il driver del JoyPad utilizzato"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_DRIVER,
      "Indica il driver audio resampler utilizzato"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_DRIVER,
      "Indica il driver della fotocamera utilizzato."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_DRIVER,
      "Indica il driver della posizione utilizzato."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_DRIVER,
      "Indica il driver del Menu utilizzato."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_RECORD_DRIVER,
      "Indica il driver per la registrazione utilizzato"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_WIFI_DRIVER,
      "Indica il driver della WiFi utilizzato"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "Filtra i file visualizzati nel filebrowser da estensioni supportate."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_WALLPAPER,
      "Seleziona un'immagine da impostare come sfondo nel menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPER,
      "Carica dinamicamente un nuovo sfondo in base al contesto."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DEVICE,
      "Sovrascrive il dispositivo audio predefinito utilizzato dal driver audio. Questo è dipendente dal driver."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DSP_PLUGIN,
      "Plugin Audio DSP che elabora l'audio prima di essere inviato al driver."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_OUTPUT_RATE,
      "Frequenza di campionamento dell'uscita audio."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_OPACITY,
      "Opacità di tutti gli elementi UI dell'overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_SCALE,
      "Scala di tutti gli elementi dell'interfaccia utente dell'overlay"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_OVERLAY_ENABLE,
      "Abilita l'overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_PRESET,
      "Seleziona un overlay dal file browser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_IP_ADDRESS,
      "Indirizzo dell'host per connettersi."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_TCP_UDP_PORT,
      "La porta dell'indirizzo IP dell' host. Può essere una porta TCP o UDP."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PASSWORD,
      "La password per il collegamento all'host netplay. Utilizzato solo in modalità host."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PUBLIC_ANNOUNCE,
      "Permette di annunciare i giochi del netplay pubblicamente. Se disattivato, i client devono connettersi manualmente anziché utilizzare la lobby pubblica."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_SPECTATE_PASSWORD,
      "La password per il collegamento all'host netplay con solo privilegi da spettatore. Utilizzato solo in modalità host."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_START_AS_SPECTATOR,
      "Avvia il netplay in modalità spettatore."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ALLOW_SLAVES,
      "Permette di connettersi in modalità slave. La modalità slave per i client richiede una piccola potenza di elaborazione su entrambi i lati, ma soffre significativamente della latenza di rete."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_REQUIRE_SLAVES,
      "Non consente le connessioni che non sono in modalità slave . Non raccomandato tranne per reti molto veloci con macchine molto deboli."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_STATELESS_MODE,
      "Il netplay viene avviato in una modalità che non richiede i salva stati. Se impostato su on,è necessaria una rete molto veloce, ma nessun riavvolgimento verrà eseguito, quindi non ci saranno i jitter del netplay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_CHECK_FRAMES,
      "La frequenza dei fotogrammi con cui il netplay verificherà che l'host e il client sono sincronizzati."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_NAT_TRAVERSAL,
      "L'hosting, tenterà di ricercare la connessione da Internet, utilizzando l' UPnP o tecnologie simili per saltare la LAN."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_STDIN_CMD_ENABLE,
      "Abilita l'interfaccia di comando stdin."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MOUSE_ENABLE,
      "Abilita i controlli del mouse all'interno del menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_POINTER_ENABLE,
      "Abilita i controlli tramite Touch all'interno del menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_THUMBNAILS,
      "Tipo di miniatura da visualizzare."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_TIMEDATE_ENABLE,
      "Mostra la data e/o l'ora attuale nel menu"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BATTERY_LEVEL_ENABLE,
      "Mostra il livello di carica della batteria all'interno del menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_WRAPAROUND,
      "Wrap-around to beginning and/or end if boundary of list is reached horizontally or vertically."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_HOST,
      "Abilita il Netplay in modalità host (server).."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_CLIENT,
      "Abilita il netplay in modalità client.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_DISCONNECT,
      "Disconnette da una connessione Netplay attiva")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_DIRECTORY,
      "Effettua la scansione di una directory per i file compatibili e li aggiunge alla raccolta.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_FILE,
      "Esegue la scansione di un file compatibile e li aggiunge alla raccolta.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SWAP_INTERVAL,
      "Utilizza un intervallo di scambio personalizzato per Vsync. Impostando un valore corretto dimezza la frequenza di aggiornamento del monitor."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVEFILES_ENABLE,
      "Ordina i file salvati in cartelle dopo che un core viene utilizzato."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVESTATES_ENABLE,
      "Ordina i salva stati in cartelle dopo che un core viene utilizzato."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_BUILDBOT_URL,
      "URL alla directory di aggiornamento del core nel buildbot di Libretro.")
MSG_HASH(MENU_ENUM_SUBLABEL_BUILDBOT_ASSETS_URL,
      "URL della directory di aggiornamento delle risorse nel buildbot Libretro.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "Dopo il download, estrae automaticamente i file contenuti negli archivi scaricati."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_REFRESH_ROOMS,
      "Scansiona nuove camere.")
MSG_HASH(MENU_ENUM_SUBLABEL_DELETE_ENTRY,
      "Rimuovi questo titolo dalla collezione")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION,
      "Visualizza ulteriori informazioni sul contenuto.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_FAVORITES,
      "Aggiunge il titolo ai tuoi preferiti.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_FAVORITES_PLAYLIST,
      "Aggiunge il titolo ai tuoi preferiti.")
MSG_HASH(MENU_ENUM_SUBLABEL_RUN,
      "Avvia il contenuto.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FILE_BROWSER_SETTINGS,
      "Regola le impostazioni del filebrowser.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_REMAPS_ENABLE,
      "Abilita i controlli personalizzati per impostazione predefinita all'avvio."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_OVERRIDES_ENABLE,
      "Abilita la configurazione personalizzata per impostazione predefinita all'avvio."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_GAME_SPECIFIC_OPTIONS,
      "Abilita le opzioni personalizzate dei core per impostazione predefinita all'avvio.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ENABLE,
      "Visualizza il nome corrente del core all'interno del menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_DATABASE_MANAGER,
      "Visualizza i database.")
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_MANAGER,
      "Visualizza le ricerche precedenti.")
MSG_HASH(MENU_ENUM_SUBLABEL_TAKE_SCREENSHOT,
      "Cattura un'immagine dello schermo.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CLOSE_CONTENT,
      "Chiude il contenuto corrente. Eventuali modifiche non salvate potrebbero essere perse."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_STATE,
      "Carica un salvataggio dallo slot attualmente selezionato")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_STATE,
      "Salva uno stato nello slot selezionato")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME,
      "Riprendi il contenuto corrente e chiude il menu rapido.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME_CONTENT,
      "Riprende il contenuto corrente e chiude il menu rapido.")
MSG_HASH(MENU_ENUM_SUBLABEL_STATE_SLOT,
      "Modifica lo slot di salvataggio selezionato.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_LOAD_STATE,
      "Se viene caricato un salvataggio, il contenuto tornerà allo stato iniziale prima del caricamento")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_SAVE_STATE,
      "Se un salvataggio è stato sovrascritto, si ritorna allo stato del salvataggio precedente.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Servizio Retro Achievements. Per maggiori informazioni, visitare il sito http://retroachievements.org"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_LIST,
      "Gestisce gli account attivi e configurati."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_META_REWIND,
      "Gestisce le impostazioni di riavvolgimento.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESTART_CONTENT,
      "Riavvia il contenuto dall'inizio.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "Salva un file di configurazione override che si applica a tutti i contenuti caricati con questo core. Avrà la precedenza sulla configurazione principale.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "Salva un file di configurazione override che si applica solo al contenuto corrente. Avrà la precedenza sulla configurazione principale.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_CHEAT_OPTIONS,
      "Imposta i codici cheat.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_OPTIONS,
      "Imposta gli shader per aumentare visivamente l'immagine.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INPUT_REMAPPING_OPTIONS,
      "Modifica i controlli per il contenuto attualmente in esecuzione.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_OPTIONS,
      "Modifica le opzioni per il contenuto attualmente in esecuzione.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_ADVANCED_SETTINGS,
      "Mostra le impostazioni avanzate per gli utenti esperti (nascosti per impostazione predefinita).")
MSG_HASH(MENU_ENUM_SUBLABEL_THREADED_DATA_RUNLOOP_ENABLE,
      "Esegue le attività su un thread separato.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_REMOVE,
      "Consente all'utente di rimuovere le voci dalla collezione.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_DIRECTORY,
      "Imposta la directory di sistema. I core possono richiedere questa directory per caricare BIOS, configurazioni specifiche del sistema, ecc.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_BROWSER_DIRECTORY,
      "Imposta la directory di avvio per il filebrowser.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DIR,
      "Di solito impostato dagli sviluppatori,perchè raggruppa le applicazioni libretro / RetroArch dove vengono visualizzate le loro attività."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPERS_DIRECTORY,
      "Directory dove vengono memorizzati gli sfondi caricati dinamicamente dal menu a seconda del contesto.")
MSG_HASH(MENU_ENUM_SUBLABEL_THUMBNAILS_DIRECTORY,
      "Qui vengono memorizzate miniature aggiuntive (boxarts / immagini , ecc.)"
      )
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_CONFIG_DIRECTORY,
      "Imposta la directory di avvio per il browser di configurazione del menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "Il numero della latenza nei fotogrammi di input per il netplay da utilizzare per nascondere la latenza di rete. Riduce il jitter e rende il netplay meno intenso di CPU, a scapito di un ritardo di input notevole.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "L'intervallo della latenza nei fotogrammi di input che può essere utilizzato per nascondere la latenza di rete. Riduce il jitter e rende il netplay meno intenso di CPU, a scapito di un imprevisto ritardo di input.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_CYCLE_TRAY_STATUS,
      "Cicli del disco corrente. Se il disco è inserito, espellerà il disco. Se il disco non è stato inserito, verrà inserito. ")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_INDEX,
      "Cambia l'indice del disco.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_OPTIONS,
      "Gestione delle immagini disco.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_IMAGE_APPEND,
      "Seleziona un'immagine disco da inserire")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENUM_THROTTLE_FRAMERATE,
      "Assicura che i fotogrammi siano attivi all'interno del menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_LAYOUT,
      "Select a different layout for the XMB interface.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_THEME,
      "Seleziona un tema diverso per l'icona. Le modifiche avranno effetto dopo il riavvio del programma.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_SHADOWS_ENABLE,
      "Abilita le ombre per tutte le icone. Questo avrà un minore rendimento")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_COLOR_THEME,
      "Seleziona uno sfondo differente con colore sfumato nel tema.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_WALLPAPER_OPACITY,
      "Modifica l'opacità dello sfondo")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MENU_COLOR_THEME,
      "Seleziona un colore di sfondo differente nel tema.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_RIBBON_ENABLE,
      "Seleziona un effetto con sfondo animato. Può essere intenso in base alla GPU a seconda dell'effetto. Se le prestazioni sono insoddisfacenti, disattivare o tornare ad un effetto più semplice.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_FONT,
      "Seleziona un altro tipo di carattere principale da utilizzare dal menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_FAVORITES,
      "Mostra la colonna preferiti all'interno del menu principale.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_IMAGES,
      "Mostra la colonna immagini all'interno del menu principale.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_MUSIC,
      "Mostra la colonna musica all'interno del menu principale.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_VIDEO,
      "Mostra la colonna video all'interno del menu principale")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_NETPLAY,
      "Mostra la colonna camere netplay all'interno del menu principale")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS,
      "Mostra la colonna impostazioni all'interno del menu principale")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_HISTORY,
      "Mostra la colonna cronologia all'interno del menu principale.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_ADD,
      "Mostra la colonna importa contenuto all'interno del menu principale.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_PLAYLISTS,
      "Mostra le colonne delle playlist all'interno del menu principale")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_SHOW_START_SCREEN,
      "Mostra la schermata di avvio nel menu. Questo viene automaticamente impostato su off dopo l'avvio del programma per la prima volta.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_HEADER_OPACITY,
      "Modifica l'opacità dell'intestazione grafica.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_FOOTER_OPACITY,
      "Modifica l'opacità grafica a piè di pagina.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_ENABLE,
      "Il menu normalmente si scala dinamicamente. Se si desidera impostare una dimensione specifica, abilitare l'opzione.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_VALUE,
      "Impostare qui la dimensione della scala personalizzata. NOTA: è necessario abilitare l'opzione 'DPI Override' per scalare a questa dimensione.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ASSETS_DIRECTORY,
      "Salva tutti i file scaricati in questa directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_REMAPPING_DIRECTORY,
      "Salva tutti i controlli remappati in questa directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_DIR_PATH,
      "Directory in cui il programma cerca contenuti o core.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_INFO_PATH,
      "Qui vengono memorizzati i file di informazioni dei core/applicazioni.")
MSG_HASH(MENU_ENUM_SUBLABEL_JOYPAD_AUTOCONFIG_DIR,
      "Se un joypad viene collegato, verrà automaticamente configurato se all'interno di questa directory è presente un file di configurazione corrispondente.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_DIRECTORY,
      "Salva tutte le collezioni in questa directory.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CACHE_DIRECTORY,
      "Se non viene impostata una directory, il contenuto estratto temporaneamente (ad esempio dagli archivi) si troverà in questa directory."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_DIRECTORY,
      "Le query salvate vengono memorizzate in questa directory.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DATABASE_DIRECTORY,
      "I database sono memorizzati in questa directory."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ASSETS_DIRECTORY,
      "Questa posizione viene interrogata per impostazione predefinita quando le interfacce di menu cercano asset caricabili, ecc."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SAVEFILE_DIRECTORY,
      "Salva tutti i file di salvataggio in questa directory. Se non è impostato, cercherà di salvare nella directory di lavoro del file di contenuto.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVESTATE_DIRECTORY,
      "Salva tutti gli stati di salvataggio in questa directory. Se non è impostato, cercherà di salvare nella directory di lavoro del file di contenuto.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCREENSHOT_DIRECTORY,
      "Directory per scaricare screenshots su.")
MSG_HASH(MENU_ENUM_SUBLABEL_OVERLAY_DIRECTORY,
      "Definisce una directory in cui l'overlay viene mantenuto per un facile accesso.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_DATABASE_PATH,
      "I file cheat sono conservati qui."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_FILTER_DIR,
      "Directory in cui vengono conservati i file di filtro audio DSP."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FILTER_DIR,
      "Directory dove vengono conservati i file del filtro video basati su CPU."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_DIR,
      "Definisce una directory in cui i file shader del video basati su GPU vengono mantenuti per un facile accesso.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_OUTPUT_DIRECTORY,
      "Le registrazioni saranno scaricate in questa directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_CONFIG_DIRECTORY,
      "Le configurazioni di registrazione saranno conservate qui.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_PATH,
      "Seleziona un altro tipo di carattere per le notifiche sullo schermo.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_APPLY_CHANGES,
      "Le modifiche alla configurazione shader avranno effetto immediatamente. Utilizzare questo se hai modificato gli shader, filtri, scala FBO, ecc.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHADER_NUM_PASSES,
      "Aumenta o diminuisce la quantità di shader pipeline. È possibile legare uno shader separato a ciascun passaggio di pipeline e configurare la sua scala e il suo filtro."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET,
      "Carica uno shader preimpostato. Lo shader pipeline sarà automaticamente impostato.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_AS,
      "Save the current shader settings as a new shader preset.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_CORE,
      "Salva le impostazioni dello shader corrente come impostazioni predefinite per questa applicazione/core.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_GAME,
      "Salva le impostazioni dello shader corrente come impostazioni predefinite per il contenuto.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PARAMETERS,
      "Consente di modificare direttamente lo shader corrente. Le modifiche non verranno salvate nel file preimpostato.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_PARAMETERS,
      "Modifica le preimpostazioni dello shader attualmente utilizzato nel menu.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_NUM_PASSES,
      "Aumenta o diminuisce la quantità di cheat."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CHEAT_APPLY_CHANGES,
      "Le modifiche sui cheat avranno effetto immediato.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_LOAD,
      "Carica un file cheat ."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_SAVE_AS,
      "Salva i cheat correnti come file di salvataggio."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SETTINGS,
      "Accesso rapido a tutte le impostazioni in-game")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INFORMATION,
      "Visualizza le informazioni relative all'applicazione/core.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_ASPECT_RATIO,
      "Floating point value for video aspect ratio (width / height), used if the Aspect Ratio is set to 'Config'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "Altezza di visualizzazione personalizzata utilizzata se il Rapporto d'aspetto è impostato su 'Custom'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "Larghezza di visualizzazione personalizzata utilizzata se il Rapporto d'aspetto è impostato su 'Custom'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_X,
      "Offset di visualizzazione personalizzata utilizzata per definire la posizione dell'asse X di visualizzazione. Queste vengono ignorate se è abilitata l'opzione 'Integer Scale' e sarà centrata automaticamente.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_Y,
      "Offset di visualizzazione personalizzata utilizzata per definire la posizione dell'asse Y di visualizzazione. Queste vengono ignorate se è abilitata l'opzione 'Integer Scale' e sarà centrata automaticamente.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_USE_MITM_SERVER,
      "Usa Relay Server")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_USE_MITM_SERVER,
      "Inoltra le connessioni da netplay attraverso un server man-in-the-middle . Utile se l'host è dietro un firewall o ha problemi NAT/UPnP")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER,
      "Aggiungi al mixer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION,
      "Aggiungi al mixer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER_BY_CURRENT_CORE,
      "Filtra per core corrente")
MSG_HASH(
      MSG_AUDIO_MIXER_VOLUME,
      "Volume globale del mixer audio"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_MIXER_VOLUME,
      "Volume globale del mixer audio(in dB). 0 dB è il volume normale e non viene applicato alcun guadagno."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_VOLUME,
      "Livello del Volume del mixer audio (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_MUTE,
      "Disattiva Mixer Audio"
      )
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_MUTE,
      "Attiva/disattiva mixer audio.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_ONLINE_UPDATER,
      "Visualizza Aggiorna Online")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_ONLINE_UPDATER,
      "Visualizza/Nasconde l'opzione 'Aggiorna Online")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_VIEWS_SETTINGS,
      "Opzioni di visualizzazione")
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_VIEWS_SETTINGS,
      "Mostra o nasconde gli elementi nella schermata del menu."
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CORE_UPDATER,
      "Visualizza Aggiorna Core")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CORE_UPDATER,
      "Mostra / nasconde la possibilità di aggiornare i core (e i file di informazioni principali).")
MSG_HASH(MSG_PREPARING_FOR_CONTENT_SCAN,
      "Preparazione per la scansione dei contenuti in corso...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_DELETE,
      "Cancella core")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_DELETE,
      "Rimuove questo core dal disco.")
MSG_HASH(MENU_ENUM_SUBLABEL_RENAME_ENTRY,
      "Rinomina la voce del titolo.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RENAME_ENTRY,
      "Rinomina")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FRAMEBUFFER_OPACITY,
      "Opacità Framebuffer")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FRAMEBUFFER_OPACITY,
      "Modifica l'opacità del framebuffer.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_FAVORITES,
      "Preferiti")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_FAVORITES,
      "Qui verrà visualizzato il contenuto che hai aggiunto a 'Preferiti'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_MUSIC,
      "Musica")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_MUSIC,
      "Qui verrà visualizzata la musica che è stata eseguita in precedenza.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_IMAGES,
      "Immmagini")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_IMAGES,
      "Qui vengono inseriti le immagini precedentemente visualizzate.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_VIDEO,
      "Video")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_VIDEO,
      "Qui vengono visualizzati i video precedentemente riprodotti.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_ICONS_ENABLE,
      "Icone del Menu")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_ICONS_ENABLE,
      "Abilita/disabilita le icone del menu visualizzate sul lato sinistro di ogni voce.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Abilita la colonna Impostazioni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Imposta una Password per abilitare la colonna Impostazioni")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD,
      "Inserisci Password")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_OK,
      "Password corretta.")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_NOK,
      "Password non corretta.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Abilita la colonna Impostazioni. È necessario un riavvio affinchè le modifiche abbiano effetto.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Fornisce una password quando si nasconde la colonna Impostazioni per poi ripristinarli dal menu, andando alla colonna Menù Principale, selezionando abilita la colonna Impostazioni e immettere la password")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_RENAME,
      "Consente all'utente di rinominare le voci nelle collezioni.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_RENAME,
      "Permette di rinominare le voci")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CORE,
      "Visualizza Carica Core")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CORE,
      "Mostra/Nasconde l'opzione 'Carica Core'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CONTENT,
      "Visualizza carica contenuto")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CONTENT,
      "Mostra/Nascondi l'opzione 'Carica contenuto'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_INFORMATION,
      "Visualizza informazioni")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_INFORMATION,
      "Mostra/Nascondi l'opzione 'Informazioni'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CONFIGURATIONS,
      "Visualizza Configurazioni")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CONFIGURATIONS,
      "Mostra/Nasconde l'opzione 'Configurazioni'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_HELP,
      "Visualizza Aiuto")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_HELP,
      "Mostra/Nascondi l'opzione 'Aiuto'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_QUIT_RETROARCH,
      "Visualizza Esci da RetroArch")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_QUIT_RETROARCH,
      "Mostra/Nasconde l'opzione 'Esci da RetroArch'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_REBOOT,
      "Visualizza Riavvia")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_REBOOT,
      "Mostra/Nasconde l'opzione 'Riavvia'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_VIEWS_SETTINGS,
      "Menu rapido")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_VIEWS_SETTINGS,
      "Mostra o nasconde gli elementi nella schermata Menu rapido.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Visualizza Effettua Screenshot")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Mostra/nasconde l'opzione 'Effettua Screenshot'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Visualizza Salva/Carica Stato")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Mostra/nasconde le opzioni per il salvataggio/caricamento dello stato.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Visualizza Annulla Salva/Carica Stato")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Mostra/nasconde le opzioni per annullare il salvataggio/caricamento dello stato.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Visualizza Aggiungi a Preferiti")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Mostra/nasconde l'opzione Aggiungi a Preferiti.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_OPTIONS,
      "Visualizza Opzioni")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_OPTIONS,
      "Mostra/nasconde l'opzione 'Opzioni'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CONTROLS,
      "Visualizza Controlli")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CONTROLS,
      "Mostra/nasconde l'opzione 'Controlli'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CHEATS,
      "Visualizza Cheats")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CHEATS,
      "Mostra/nasconde l'opzione 'Cheats'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SHADERS,
      "Visualizza Shaders")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SHADERS,
      "Mostra/nasconde l'opzione 'Shaders'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Visualizza Salva gli Override dei core")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Mostra/nasconde l'opzione 'Salva gli Override dei core'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Visualizza Salva gli Override dei giochi")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Mostra/nasconde l'opzione 'Salva gli Override dei giochi'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_INFORMATION,
      "Visualizza Informazioni")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_INFORMATION,
      "Mostra/nasconde l'opzione 'Informazioni'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DISABLE_KIOSK_MODE,
      "Disabilita modalità Kiosk ")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_DISABLE_KIOSK_MODE,
      "Disabilita la modalità kiosk. È necessario un riavvio affinchè la modifica abbia effetto.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENABLE_KIOSK_MODE,
      "Abilita modalità Kiosk ")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENABLE_KIOSK_MODE,
      "Protegge l'installazione nascondendo tutte le impostazioni relative alla configurazione.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_KIOSK_MODE_PASSWORD,
      "Imposta una Password per disattivare la modalità Kiosk")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_KIOSK_MODE_PASSWORD,
      "E' possibile fornire una password quando è attiva la modalità Kiosk ed è possibile disabilitarla successivamente dal menu, andare al 'Menu principale', selezionare 'Disattiva modalità Kiosk' e inserere la password.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD,
      "Inserisci Password")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_OK,
      "Password corretta.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_NOK,
      "Password non corretta.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Aggiungi automaticamente il contenuto alla playlist")
MSG_HASH(MENU_ENUM_SUBLABEL_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Esegue automaticamente la scansione dei contenuti caricati in modo che vengano visualizzati all'interno delle playlist.")
MSG_HASH(MSG_SCANNING_OF_FILE_FINISHED,
      "Scansione del file completata")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_QUALITY,
      "Qualità del Resampler Audio")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_QUALITY,
      "Abbassare questo valore per favorire prestazioni/bassa latenza rispetto alla qualità audio, aumentare se si desidera una migliore qualità audio a scapito delle prestazioni/minore latenza.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATISTICS_SHOW,
      "Mostra statistiche")
MSG_HASH(MENU_ENUM_SUBLABEL_STATISTICS_SHOW,
      "Mostra statistiche tecniche su schermo.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_ENABLE,
      "Abilita riempimento dei bordi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_THICKNESS_ENABLE,
      "Attiva lo spessore del riempimento del bordo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BACKGROUND_FILLER_THICKNESS_ENABLE,
      "Abilita lo spessore del riempimento dello sfondo")
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION, "Solo per schermi CRT a 15 kHz. Tenta di utilizzare la risoluzione esatta core/gioco e la frequenza di aggiornamento.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION, "CRT SwitchRes") 
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION_SUPER, "Quando CRT SwitchRes è abilitato, forza la risoluzione orizzontale ultrawide per minimizzare il cambio di modalità.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION_SUPER, "CRT Super Risoluzione") 
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_REWIND,
      "Mostra impostazioni di riavvolgimento")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_REWIND,
      "Mostra/nascondi le opzioni di riavvolgimento.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_LATENCY,
      "Mostra/nascondi le opzioni di latenza.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_LATENCY,
      "Mostra le impostazioni di latenza")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_OVERLAYS,
      "Mostra/nascondi le opzioni di Sovrapposizione.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_OVERLAYS,
      "Mostra le impostazioni di sovrapposizione")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE_MENU,
      "Abilita l'audio del menu")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_ENABLE_MENU,
      "Abilita o disabilita il suono del menu.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_SETTINGS,
      "Mixer Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_SETTINGS,
      "View and/or modify audio mixer settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_OVERRIDE_OPTIONS,
      "Configuration Override options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_OVERRIDE_OPTIONS,
      "Options for overriding the global configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY,
      "Will start playback of the audio stream. Once finished, it will remove the current audio stream from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_LOOPED,
      "Will start playback of the audio stream. Once finished, it will loop and play the track again from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Will start playback of the audio stream. Once finished, it will jump to the next audio stream in sequential order and repeat this behavior. Useful as an album playback mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_STOP,
      "This will stop playback of the audio stream, but not remove it from memory. You can start playing it again by selecting 'Play'.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_REMOVE,
      "This will stop playback of the audio stream and remove it entirely from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_VOLUME,
      "Adjust the volume of the audio stream.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER,
      "Add this audio track to an available audio stream slot. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER_AND_PLAY,
      "Add this audio track to an available audio stream slot and play it. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY,
      "Play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_LOOPED,
      "Play (Looped)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Play (Sequential)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_STOP,
      "Stop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_REMOVE,
      "Remove")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_VOLUME,
      "Volume")
